<?php
/*
Plugin Name: Plugin Rifa
Plugin URI: https://diogenesjunior.com.br/pluginrifa
Description: Plugin para administração e configurações de funcionalidades de RIFA para WordPress+WooCommerce
Version: 2.15.2
Author: Diogenes Junior
Author URI: http://www.diogenesjunior.com.br
*/


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   URLs DE ATUALIZAÇÕES DO PLUGIN
*
*
*  ------------------------------------------------------------------------------------------------
*/
require "update/plugin-update-checker.php";
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
  'https://www.diogenesjunior.com.br/diretorios/plugins/atualizacoes.json',
  __FILE__, //Full path to the main plugin file or functions.php.
  'plugin-rifa'
);


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   VERIFICAR VERSOES WORDPRESS E PHP
*   Função escrita por Kyle Phillips https://github.com/kylephillips
*
*
*  ------------------------------------------------------------------------------------------------
*/
register_activation_hook( __FILE__, 'pluginrifa_check_versions' );
function pluginrifa_check_versions( $wp = '5.0', $php = '5.6.0' ) {
    global $wp_version;
    if ( version_compare( PHP_VERSION, $php, '<' ) ) $flag = 'PHP';
    elseif ( version_compare( $wp_version, $wp, '<' ) ) $flag = 'WordPress';
    else return;
    $version = 'PHP' == $flag ? $php : $wp;
    
    if (function_exists('deactivate_plugins')){
        deactivate_plugins( basename( __FILE__ ) );
    }
    
    wp_die('<p>O <strong>Plugin Rifa WordPress+WooCommerce</strong> precisa do '.$flag.'  versão '.$version.' ou superior.</p>','Não conseguimos ativar o plugin :(',  array( 'response'=>200, 'back_link'=>TRUE ) );
}

/**
*  ------------------------------------------------------------------------------------------------
*
*
*   REGISTERS
*
*
*  ------------------------------------------------------------------------------------------------
*/
add_theme_support( 'woocommerce' );

add_action( 'wp_enqueue_scripts', 'misha_register_and_enqueue' );
 
function misha_register_and_enqueue() {

	$args = array('homeurl' => get_site_url());
   
	wp_register_script( 'scripts-rifa', get_site_url()."/wp-content/plugins/plugin-rifa/js/scripts-rifa.js?v=".date('dmYHisu') );
	wp_enqueue_script( 'scripts-rifa', add_query_arg( $args, get_site_url() ) );
    
	wp_enqueue_style( 'style-rifa', get_site_url()."/wp-content/plugins/plugin-rifa/css/style.css?v=".date('dmYHisu') );
	
}

// CARREGAR OS ESTILOS APENAS NO ADMIN
function admin_style_pluginrifa() {

    // JQUERY CONFIRM
    wp_register_script( 'jquery-confirm', "https://cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.2/jquery-confirm.min.js", array( 'jquery' ), '1.0.0', true );

    wp_enqueue_script( 'jquery-confirm' );
    
    wp_enqueue_style( 'jquery-confirm-css', "https://cdnjs.cloudflare.com/ajax/libs/jquery-confirm/3.3.2/jquery-confirm.min.css" );

    wp_enqueue_style( 'rifa-admin-css', get_site_url()."/wp-content/plugins/plugin-rifa/css/admin.css?v=280" );

}

add_action('admin_enqueue_scripts', 'admin_style_pluginrifa');

function disable_emojis_plugin_rifa() {
  remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
  remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
  remove_action( 'wp_print_styles', 'print_emoji_styles' );
  remove_action( 'admin_print_styles', 'print_emoji_styles' );  
  remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
  remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );  
  remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
  add_filter( 'tiny_mce_plugins', 'disable_emojis_tinymce' );
}

add_action( 'init', 'disable_emojis_plugin_rifa' );

/**
 * Filter function used to remove the tinymce emoji plugin.
 * 
 * @param    array  $plugins  
 * @return   array  Difference betwen the two arrays
 */

function disable_emojis_tinymce( $plugins ) {
  if ( is_array( $plugins ) ) {
    return array_diff( $plugins, array( 'wpemoji' ) );
  } else {
    return array();
  }
}


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   CRIAR OS CUSTOM FIELDS PARA OS PRODUTOS DA RIFA
*
*
*  ------------------------------------------------------------------------------------------------
*/

if( function_exists('acf_add_local_field_group') ):

acf_add_local_field_group(array(
	'key' => 'group_5fd7d113c1e6d',
	'title' => 'Opções das rifas',
	'fields' => array(
		array(
      'key' => 'field_5fd7d156c1780',
      'label' => 'Número de dígitos por cota',
      'name' => 'numero_globos',
      'type' => 'text',
      'instructions' => 'Apenas os números 3, 4, 5 e 6 são aceitos',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '4',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11,
    ),
		array(
			'key' => 'field_5fd7d156c1766',
			'label' => 'Número de cotas',
			'name' => 'numero_de_cotas',
			'type' => 'text',
			'instructions' => 'Apenas números, por exemplo: 100 ou 5000. Se você irá utilizar mais de 1500 cotas, recomendados usar apenas os shortcodes da versão 2, para que não tenha problemas de velocidade no carregamento. Acima de 2500 cotas, a sua página pode levar um tempo considerável para carregar.',
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'default_value' => '',
			'placeholder' => '',
			'prepend' => '',
			'append' => '',
			'maxlength' => 11,
		),
    array(
      'key' => 'field_6100c462f0fac',
      'label' => 'Tipo de cota',
      'name' => 'tipo_de_cota',
      'type' => 'select',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'choices' => array(
        'Cota quadrada' => 'Cota quadrada',
        'Cota redonda' => 'Cota redonda',
      ),
      'default_value' => false,
      'allow_null' => 0,
      'multiple' => 0,
      'ui' => 0,
      'return_format' => 'value',
      'ajax' => 0,
      'placeholder' => '',
    ),
    array(
      'key' => 'field_5fd7d126c1767',
      'label' => 'Cor de fundo ao selecionar cota',
      'name' => 'cor_de_fundo_selecao',
      'type' => 'color_picker',
      'instructions' => 'Exemplo #000, ou rgba(000,000,000,000)',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 22
    ),
    array(
      'key' => 'field_5fd7d126c1768',
      'label' => 'Cor de fundo cota selecionada modal',
      'name' => 'cor_de_fundo_selecao_modal_rodape',
      'type' => 'color_picker',
      'instructions' => 'cor do número da cota selecionada no modal flutuante',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 22
    ),
    array(
      'key' => 'field_5fd7d126c1769',
      'label' => 'Cor de fundo botão finalizar compra',
      'name' => 'cor_de_fundo_btn_finalizar_compra',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 22
    ),
    array(
      'key' => 'field_5fd7d126c1770',
      'label' => 'Cor do texto botão finalizar compra',
      'name' => 'cor_do_texto_btn_finalizar_compra',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 22
    ),
    array(
      'key' => 'field_5fd7d126c1771',
      'label' => 'Cor da borda da cota antes da seleção',
      'name' => 'cor_do_borda_cota_antes_selecao',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 22
    ),
    array(
      'key' => 'field_5fd7d126c1772',
      'label' => 'Cor da borda abas Livres e Reservadas',
      'name' => 'cor_do_borda_abas_livres_reservadas',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 22
    ),
    array(
      'key' => 'field_5fd7d126c1773',
      'label' => 'Número máximo de cotas que um usuário pode comprar por vez',
      'name' => 'num_maximo_reservas',
      'type' => 'text',
      'instructions' => 'Apenas números, deixar em branco ou zero para livre',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),
    array(
      'key' => 'field_5fd7d126c1775',
      'label' => 'Mensagem retorno ao atingir o número máximo',
      'name' => 'msg_num_maximo_reservas',
      'type' => 'text',
      'instructions' => 'Mensagem que será retornada ao usuário após atingir o número máximo de reservas',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => 'Você já selecionou o número máximo de cotas disponíveis para compra por usuário. Remova algumas das cotas selecionadas para concluir a compra.',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 200
    ),
    array(
      'key' => 'field_5fd7d126c1780',
      'label' => 'Mensagem explicativa número máximo',
      'name' => 'msg_explicativa_num_maximo',
      'type' => 'text',
      'instructions' => 'Mensagem que será exibida na barra inferior ao atingir o número máximo',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => 'Remova algumas das cotas selecionadas para concluir a compra.',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 200
    ),
    array(
      'key' => 'field_5fd7d126c1800',
      'label' => 'Número mínimo de cotas que um usuário deve comprar por vez',
      'name' => 'num_minimo_reservas',
      'type' => 'text',
      'instructions' => 'Apenas números, deixar em branco ou zero para livre',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),
    array(
      'key' => 'field_5fd7d126c1776',
      'label' => 'Mensagem enquanto não tiver o número mínimo de reservas',
      'name' => 'msg_num_minimo_reservas',
      'type' => 'text',
      'instructions' => 'Mensagem que será retornada ao usuário enquanto não atingir o número mínimo de reservas',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => 'Você não selecinou o número mínimo de cotas obrigatórias por compra. Adicione mais cotas antes de concluir sua compra.',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 200
    ),
    array(
      'key' => 'field_5fd7d126c1781',
      'label' => 'Mensagem explicativa número mínimo',
      'name' => 'msg_explicativa_num_minimo',
      'type' => 'text',
      'instructions' => 'Mensagem que será exibida na barra inferior enquanto não alcançar o número mínimo',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => 'Adicione mais cotas antes de concluir a compra.',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 200
    ),
    array(
      'key' => 'field_5fd7d126c1774',
      'label' => 'Texto botão Finalizar Compra',
      'name' => 'texto_btn_finalizar_compra',
      'type' => 'text',
      'instructions' => 'Texto botão Finalizar Compra',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => 'FINALIZAR COMPRA',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 100
    ),
    array(
      'key' => 'field_5fd7d126c1777',
      'label' => 'Cor de fundo da reserva indisponível (reservada) no modo de exibição "Todas Juntas"',
      'name' => 'cor_reserva_juntas',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),
    array(
      'key' => 'field_5fd7d126c1778',
      'label' => 'Cor do texto da reserva indisponível (reservada) no modo de exibição "Todas Juntas"',
      'name' => 'cor_texto_juntas',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),

    array(
      'key' => 'field_5fd7d126c1757',
      'label' => 'Cor de fundo da reserva indisponível (rifa presencial) no modo de exibição "Todas Juntas"',
      'name' => 'cor_reserva_juntas_rifa_presencial',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),
    array(
      'key' => 'field_5fd7d126c1758',
      'label' => 'Cor do texto da reserva indisponível (rifa presencial) no modo de exibição "Todas Juntas"',
      'name' => 'cor_texto_juntas_rifa_presencial',
      'type' => 'color_picker',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),


    array(
      'key' => 'field_5fd7d126c1730',
      'label' => 'Cor de fundo da reserva comprada no modo de exibição "Todas Juntas"',
      'name' => 'cor_comprada_juntas',
      'type' => 'color_picker',
      'instructions' => 'Exemplo: #1976D2',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),
    array(
      'key' => 'field_5fd7d126c1731',
      'label' => 'Cor do texto da reserva comprada no modo de exibição "Todas Juntas"',
      'name' => 'cor_texto_compradas_juntas',
      'type' => 'color_picker',
      'instructions' => 'Exemplo: #fff',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 11
    ),
    array(
      'key' => 'field_5fd7d126c1732',
      'label' => 'Texto Tooltip quando o número estiver reservado',
      'name' => 'texto_tooltip_reserva',
      'type' => 'text',
      'instructions' => 'Por exemplo: Número reservado',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => ''
    ),
    array(
      'key' => 'field_5fd7d126c1720',
      'label' => 'Texto Tooltip quando o número estiver reservado (Rifa presencial)',
      'name' => 'texto_tooltip_reserva_presencial',
      'type' => 'text',
      'instructions' => 'Por exemplo: Reserva presencial',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => 'Reserva presencial',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => ''
    ),
    array(
      'key' => 'field_6090bf9a3c1e9',
      'label' => 'Exibir nome do comprador ou texto padrão?',
      'name' => 'exibir_nome_do_comprador_ou_texto_padrao',
      'type' => 'select',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'choices' => array(
        'Texto padrão' => 'Texto padrão',
        'Nome comprador' => 'Nome comprador',
      ),
      'default_value' => false,
      'allow_null' => 0,
      'multiple' => 0,
      'ui' => 0,
      'return_format' => 'value',
      'ajax' => 0,
      'placeholder' => '',
    ),
    array(
      'key' => 'field_5fd7d126c1733',
      'label' => 'Texto Tooltip quando o número estiver comprado',
      'name' => 'texto_tooltip_comprado',
      'type' => 'text',
      'instructions' => 'Por exemplo: Número comprado',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => ''
    ),
    array(
      'key' => 'field_5fd7d126c1779',
      'label' => 'Caso selecione o shortcode "exibir_compradores", exibir o e-mail?',
      'name' => 'exibir_email',
      'type' => 'text',
      'instructions' => 'Digite "n" para não deixe em branco para sim',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => 1
    ),
    array(
      'key' => 'field_61185ed590977',
      'label' => 'Cores Modelos TODAS (Modelo 4)',
      'name' => 'cores_modelos_todas',
      'type' => 'group',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '50',
        'class' => '',
        'id' => '',
      ),
      'layout' => 'table',
      'sub_fields' => array(
        array(
          'key' => 'field_61185eff90978',
          'label' => 'Cor de fundo ABA TODAS',
          'name' => 'cor_de_fundo_aba_todas',
          'type' => 'color_picker',
          'instructions' => 'Também será usado na aba participantes',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#dddfde',
        ),
        array(
          'key' => 'field_61185f1390979',
          'label' => 'Cor do texto e borda ABA TODAS',
          'name' => 'cor_do_texto_e_borda_aba_todas',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#000000',
        ),
      ),
    ),
    array(
      'key' => 'field_611868bd2ca2c',
      'label' => 'Cores Modelos LIVRES  (Modelo 4)',
      'name' => 'cores_modelos_livres',
      'type' => 'group',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '50',
        'class' => '',
        'id' => '',
      ),
      'layout' => 'table',
      'sub_fields' => array(
        array(
          'key' => 'field_611868bd2ca2f',
          'label' => 'Cor de fundo ABA LIVRES',
          'name' => 'cor_de_fundo_aba_livres',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#ffffff',
        ),
        array(
          'key' => 'field_611868bd2ca30',
          'label' => 'Cor do texto e borda ABA LIVRES',
          'name' => 'cor_do_texto_e_borda_aba_livres',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#000000',
        ),
      ),
    ),
    array(
      'key' => 'field_611868c02ca35',
      'label' => 'Cores Modelos RESERVADAS  (Modelo 4)',
      'name' => 'cores_modelos_reservadas',
      'type' => 'group',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '50',
        'class' => '',
        'id' => '',
      ),
      'layout' => 'table',
      'sub_fields' => array(
        array(
          'key' => 'field_611868c02ca3a',
          'label' => 'Cor de fundo ABA RESERVADAS',
          'name' => 'cor_de_fundo_aba_reservadas',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#c6c320',
        ),
        array(
          'key' => 'field_611868c02ca3b',
          'label' => 'Cor do texto e borda ABA RESERVADAS',
          'name' => 'cor_do_texto_e_borda_aba_reservadas',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#000000',
        ),
      ),
    ),
    array(
      'key' => 'field_611868c22ca3e',
      'label' => 'Cores Modelos PAGAS  (Modelo 4)',
      'name' => 'cores_modelos_pagas',
      'type' => 'group',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '50',
        'class' => '',
        'id' => '',
      ),
      'layout' => 'table',
      'sub_fields' => array(
        array(
          'key' => 'field_611868c22ca45',
          'label' => 'Cor de fundo ABA PAGAS',
          'name' => 'cor_de_fundo_aba_pagas',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#48b82f',
        ),
        array(
          'key' => 'field_611868c22ca46',
          'label' => 'Cor do texto e borda ABA PAGAS',
          'name' => 'cor_do_texto_e_borda_aba_pagas',
          'type' => 'color_picker',
          'instructions' => '',
          'required' => 0,
          'conditional_logic' => 0,
          'wrapper' => array(
            'width' => '',
            'class' => '',
            'id' => '',
          ),
          'default_value' => '#000000',
        ),
      ),
    ),
	),
	'location' => array(
		array(
			array(
				'param' => 'post_type',
				'operator' => '==',
				'value' => 'product',
			),
		),
	),
	'menu_order' => 0,
	'position' => 'acf_after_title',
	'style' => 'default',
	'label_placement' => 'top',
	'instruction_placement' => 'label',
	'hide_on_screen' => '',
	'active' => true,
	'description' => '',
));



acf_add_local_field_group(array(
  'key' => 'group_605bf2ace0b3e',
  'title' => 'Opções Modelo de Página Especial Rifa',
  'fields' => array(
    array(
      'key' => 'field_605bf307d18c0',
      'label' => 'Logo',
      'name' => '',
      'type' => 'tab',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'placement' => 'left',
      'endpoint' => 0,
    ),
    array(
      'key' => 'field_605bf31ed18c1',
      'label' => 'Imagem do logo',
      'name' => 'imagem_do_logo_mpf',
      'type' => 'image',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'return_format' => 'url',
      'preview_size' => 'full',
      'library' => 'all',
      'min_width' => '',
      'min_height' => '',
      'min_size' => '',
      'max_width' => '',
      'max_height' => '',
      'max_size' => '',
      'mime_types' => '',
    ),
    array(
      'key' => 'field_605bf374d18c5',
      'label' => 'Menu',
      'name' => '',
      'type' => 'tab',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'placement' => 'left',
      'endpoint' => 0,
    ),
    array(
      'key' => 'field_605bf394d18c6',
      'label' => 'Título menu 1',
      'name' => 'titulo_menu_1',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3d5d18cc',
      'label' => 'URL menu 1',
      'name' => 'url_menu_1',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3bfd18c8',
      'label' => 'Título menu 2',
      'name' => 'titulo_menu_2',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3e1d18cd',
      'label' => 'URL menu 2',
      'name' => 'url_menu_2',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3c8d18c9',
      'label' => 'Título menu 3',
      'name' => 'titulo_menu_3',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3e7d18ce',
      'label' => 'URL menu 3',
      'name' => 'url_menu_3',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3cad18ca',
      'label' => 'Título menu 4',
      'name' => 'titulo_menu_4',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3efd18cf',
      'label' => 'URL menu 4',
      'name' => 'url_menu_4',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3cdd18cb',
      'label' => 'Título menu 5',
      'name' => 'titulo_menu_5',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf3f5d18d0',
      'label' => 'URL menu 5',
      'name' => 'url_menu_5',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf344d18c2',
      'label' => 'Intro',
      'name' => '',
      'type' => 'tab',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'placement' => 'left',
      'endpoint' => 0,
    ),
    array(
      'key' => 'field_605bf34ed18c3',
      'label' => 'Título principal',
      'name' => 'titulo_principal_mpf',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf35ad18c4',
      'label' => 'Subtítulo principal',
      'name' => 'subtitulo_principal_mpf',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf404d18d1',
      'label' => 'Prêmio',
      'name' => '',
      'type' => 'tab',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'placement' => 'left',
      'endpoint' => 0,
    ),
    array(
      'key' => 'field_605bf411d18d2',
      'label' => 'Imagem de destaque',
      'name' => 'imagem_de_destaque_mpf',
      'type' => 'image',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'return_format' => 'url',
      'preview_size' => 'full',
      'library' => 'all',
      'min_width' => '',
      'min_height' => '',
      'min_size' => '',
      'max_width' => '',
      'max_height' => '',
      'max_size' => '',
      'mime_types' => '',
    ),
    array(
      'key' => 'field_605bf425d18d3',
      'label' => 'Iframe vídeo youtube',
      'name' => 'iframe_video_youtube',
      'type' => 'textarea',
      'instructions' => 'Se você usar essa opção, não vamos exibir a imagem no destaque',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'maxlength' => '',
      'rows' => '',
      'new_lines' => '',
    ),
    array(
      'key' => 'field_605bf479d18d4',
      'label' => 'Título',
      'name' => 'titulo_premio_mpf',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf487d18d5',
      'label' => 'Texto descritivo',
      'name' => 'texto_descritivo_mpf',
      'type' => 'wysiwyg',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'tabs' => 'all',
      'toolbar' => 'full',
      'media_upload' => 1,
      'delay' => 0,
    ),
    array(
      'key' => 'field_605bf49fd18d6',
      'label' => 'Lateral',
      'name' => '',
      'type' => 'tab',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'placement' => 'left',
      'endpoint' => 0,
    ),
    array(
      'key' => 'field_605bf5d1d18d7',
      'label' => 'Texto parte superior barra de progresso',
      'name' => 'texto_parte_superior_barra_de_progresso',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf5e1d18d8',
      'label' => 'Shortcode barra de progresso',
      'name' => 'shortcode_barra_de_progresso',
      'type' => 'wysiwyg',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'tabs' => 'all',
      'toolbar' => 'full',
      'media_upload' => 1,
      'delay' => 0,
    ),
    array(
      'key' => 'field_605bf5f5d18d9',
      'label' => 'Subtítulo preço',
      'name' => 'subtitulo_preco',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf5fcd18da',
      'label' => 'Preço',
      'name' => 'preco',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf603d18db',
      'label' => 'Texto antes do botão',
      'name' => 'texto_antes_do_botao',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf60bd18dc',
      'label' => 'Texto botões azul',
      'name' => 'texto_botoes_azul',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf61fd18dd',
      'label' => 'Rodapé',
      'name' => '',
      'type' => 'tab',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'placement' => 'left',
      'endpoint' => 0,
    ),
    array(
      'key' => 'field_605bf62fd18de',
      'label' => 'Telefone de contato',
      'name' => 'telefone_de_contato',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf636d18df',
      'label' => 'E-mail de contato',
      'name' => 'e-mail_de_contato',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
    array(
      'key' => 'field_605bf644d18e0',
      'label' => 'Logo selos de pagamento',
      'name' => 'logo_selos_de_pagamento',
      'type' => 'image',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'return_format' => 'url',
      'preview_size' => 'full',
      'library' => 'all',
      'min_width' => '',
      'min_height' => '',
      'min_size' => '',
      'max_width' => '',
      'max_height' => '',
      'max_size' => '',
      'mime_types' => '',
    ),
    array(
      'key' => 'field_605bf657d18e1',
      'label' => 'Texto final',
      'name' => 'texto_final',
      'type' => 'text',
      'instructions' => '',
      'required' => 0,
      'conditional_logic' => 0,
      'wrapper' => array(
        'width' => '',
        'class' => '',
        'id' => '',
      ),
      'default_value' => '',
      'placeholder' => '',
      'prepend' => '',
      'append' => '',
      'maxlength' => '',
    ),
  ),
  'location' => array(
    array(
      array(
        'param' => 'page_template',
        'operator' => '==',
        'value' => 'templates/rifa-pages.php',
      ),
    ),
  ),
  'menu_order' => 0,
  'position' => 'acf_after_title',
  'style' => 'default',
  'label_placement' => 'top',
  'instruction_placement' => 'label',
  'hide_on_screen' => '',
  'active' => true,
  'description' => '',
));



endif;

// GARANTIR QUE O ACF SEJA INSTALADO
add_action( 'admin_notices', 'my_theme_dependencies' );

function my_theme_dependencies() {
  if( ! function_exists('acf_add_local_field_group') )
    echo '<div class="error"><p>' . __( 'Atenção: Plugin Rifa precisa do plugin <b>Advanced Custom Fields</b> instalado para funcionar', 'my-theme' ) . '</p></div>';
}

/**
*  ------------------------------------------------------------------------------------------------
*
*
*   PÁGINA DE INSERÇÕES ADMIN
*
*
*  ------------------------------------------------------------------------------------------------
*/

 if(!class_exists('RationalOptionPages')){
   
   require_once('includes/RationalOptionPages.php');
 
 }

$pages = array(
	'sample-page'	=> array(
		'page_title'	=> __( 'Plugin Rifa', 'sample-domain' ),
		'sections'		=> array(
			'section-one'	=> array(
				'title'			=> " ",
				'text'			=> " ",
				'include'		=> plugin_dir_path( __FILE__ ) . '/templates/dashboard.php',
			),
		),
	),
   'sub-page-two'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Shortcodes', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Shortcodes do plugin",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/css-rifa.php',
        ),
      ),
    ),
   'sub-page-three'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Manual de Uso', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Manual de Uso",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/manual-rifa.php',
        ),
      ),
    ),
   /*
   'sub-page-four'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Sorteio V1', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Sorteio",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/sorteio.php',
        ),
      ),
    ),
   'sub-page-four-2'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Sorteio V2', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Sorteio",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/sorteio-v2.php',
        ),
      ),
    ),
    */
   'sub-page-five'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Exportar Excel', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Exportar Excel",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/excel.php',
        ),
      ),
    ),
   /*'sub-page-six'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Liberar/Exportar Cotas', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Exportar Excel",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/cotas.php',
        ),
      ),
    ),*/
   'sub-page-seven'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Editar pedidos', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => " ",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/editar-pedidos.php',
        ),
      ),
    ),
   'sub-page-eight'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Outros Plugins', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Outros Plugins",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/outros-plugins.php',
        ),
      ),
    ),
   'sub-page-nine'  => array(
      'title'     => " ",
      'parent_slug' => 'plugin_rifa',
      'page_title'  => __( 'Reservas Presenciais', 'sample-domain' ),
      'sections'    => array(
        'section-one' => array(
          'title'     => "Reservas Presenciais",
          'text'      => " ",
          'include'   => plugin_dir_path( __FILE__ ) . '/templates/rifa-presencial.php',
        ),
      ),
    )
);

$option_page = new RationalOptionPages( $pages );




// REGISTRAR NOVOS STATUS DE PEDIDOS
function register_awaiting_shipment_order_status_rifa() {
    register_post_status( 'wc-rifa-presencial', array(
        'label'                     => 'Rifa Presencial',
        'public'                    => true,
        'exclude_from_search'       => false,
        'show_in_admin_all_list'    => true,
        'show_in_admin_status_list' => true,
        'label_count'               => _n_noop( 'Rifa presencial (%s)', 'Rifas presenciais (%s)' )
    ) );
}
add_action( 'init', 'register_awaiting_shipment_order_status_rifa' );


// Add New Order Statuses to WooCommerce
function wpex_wc_add_order_statuses_rifa( $order_statuses ) {

    $order_statuses['wc-rifa-presencial'] = _x( 'Rifa Presencial', 'WooCommerce Order status', 'text_domain' );
  
    return $order_statuses;

}
add_filter( 'wc_order_statuses', 'wpex_wc_add_order_statuses_rifa' );


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   ADICIONAR AO ITEM DO CARRINHO OS NÚMEROS DA RIFA ESCOLHIDOS PELO USUÁRIO
*
*
*  ------------------------------------------------------------------------------------------------
*/





/**
*  ------------------------------------------------------------------------------------------------
*
*
*   METABOX DO ATALHO DO COMPROVANTE PARA O ADMIN
*
*
*  ------------------------------------------------------------------------------------------------
*/
// DECLARAR AS METASBOXES
function call_metaBoxPluginRifa2021() {
    new metaBoxPluginRifa2021();
}
 
if ( is_admin() ) {
    add_action( 'load-post.php',     'call_metaBoxPluginRifa2021' );
    add_action( 'load-post-new.php', 'call_metaBoxPluginRifa2021' );
}
 
/**
 * The Class.
 */
class metaBoxPluginRifa2021 {
 
    /**
     * Hook into the appropriate actions when the class is constructed.
     */
    public function __construct() {
        add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
    }
 
    /**
     * Adds the meta box container.
     */

    public function add_meta_box( $post_type ) {
        
      
        $post_types = array( 'product' );
 
        if ( in_array( $post_type, $post_types ) ) {

            add_meta_box(
                'some_meta_box_name',
                __( 'Exportar números Rifa', 'textdomain' ),
                array( $this, 'render_meta_box_content' ),
                $post_type,
                'advanced',
                'high'
            );

            add_meta_box(
                'some_meta_box_name2',
                __( 'Sorteio Rifa', 'textdomain' ),
                array( $this, 'render_meta_box_content_sorteio' ),
                $post_type,
                'advanced',
                'high'
            );
           
        }


    }
 
     // EXPORTAR 
     public function render_meta_box_content( $post ) {

         $order_id = $_GET["post"];
         
         ?>

           <h2 style="padding-left:0px;font-size: 22px;">Exportar números Rifa para Excel</h2>
           <p>
             Será gerada uma lista Excel (XLSX) com os números vendidos desse produto.
           </p>
           <p>
             <a href="admin.php?page=exportar_excel&produto=<?php echo $order_id; ?>&v=2" class="acf-button button button-primary" title="Exportar">
               Exportar números Rifa para Excel
             </a>
           </p>

         <?php
        
        
      }

      // SORTEIO
      public function render_meta_box_content_sorteio( $post ) {

         $order_id = $_GET["post"];

         $rifa = $order_id;

         $titulo_produto = get_the_title($rifa);

         $pedidos = get_orders_ids_by_product_id($rifa);
      
      ?>

        <style type="text/css">
          #resultadoSorteio{
            font-size: 1.2em;
          }
          #resultadoSorteio td{
            padding: 10px;
            border-bottom: 1px solid #ccc;
          }

        </style>

        <h2 style="padding-left:0px;font-size: 22px;">Sortear um número participante:</h2>
        <p>
          - Um dos números que estiver com pagamento confirmado (participante) será sorteado.<br>
          - Esse sorteio não encerra ou fecha a Rifa, para isso, você precisa remover o shortcode ou a página manualmente.<br>
          - O número sorteado não será notificado de forma automática, você precisa comunicá-lo manualmente.<br>
          - Você pode realizar esse sorteio quantas vezes quiser.
        </p>
        <script type="text/javascript">

             function shuffle(array) {
                  var currentIndex = array.length,  randomIndex;

                  // While there remain elements to shuffle...
                  while (0 !== currentIndex) {

                    // Pick a remaining element...
                    randomIndex = Math.floor(Math.random() * currentIndex);
                    currentIndex--;

                    // And swap it with the current element.
                    [array[currentIndex], array[randomIndex]] = [
                      array[randomIndex], array[currentIndex]];
                  }

                  return array;
                } 
            
            var numeros = [
            <?php 

              $a = 0;
              $b = 0;
              $valores = array();
              $array_cotas = array();
              $e = 0;
              $linhaEx = 1;

              while($a<count($pedidos)):

                $order = wc_get_order( $pedidos[$a] );

                $array_cotas[$b]["status"] = $order->get_status();

                 if($array_cotas[$b]["status"]=="completed" || $array_cotas[$b]["status"]=="processing" || $array_cotas[$b]["status"]=="rifa-presencial"):

                      $array_cotas[$b]["cotas_escolhidas"] = get_post_meta( $order->get_order_number(), 'billing_cotasescolhidas', true );

                      $array_cotas[$b]["primeiro_nome"] = $order->get_billing_first_name();
                      $array_cotas[$b]["ultimo_nome"] = $order->get_billing_last_name();
                      $array_cotas[$b]["email"] = $order->get_billing_email();
                      $array_cotas[$b]["phone"] = $order->get_billing_phone();

                      /*
                      $lista[$linhaEx] = [$order->get_order_number(), $array_cotas[$b]["primeiro_nome"]." ".$array_cotas[$b]["ultimo_nome"], $array_cotas[$b]["email"], "N ".$array_cotas[$b]["cotas_escolhidas"], $titulo_produto];
                                            $linhaEx++;
                      */

                      $numeros = explode(",",$array_cotas[$b]["cotas_escolhidas"]);

                      $n = 0;
                      while($n<count($numeros)):
                        $num = $numeros[$n];
                        if($num!=""):
                        
                        echo '"<tr><td><b>Pedido</b></td><td><b>Cliente</b></td><td><b>Produto</b></td><td><b>Número</b></td></tr><tr><td>'.$order->get_order_number().'</td><td>'.$array_cotas[$b]["email"].'</td><td>'.$titulo_produto.'</td><td>'.$num.'</td></tr>",';
                                          
                        endif;

                        $n++;
                      endwhile;


                      $b++;

                 endif;
         
                $a++;
              endwhile;


            ?>,];


            //console.log(numeros);

            function fazerSorteio(){

              numeros = shuffle(numeros);
              jQuery("#resultadoSorteio").html(numeros[0]);

          }


        </script>


        <table id="resultadoSorteio"></table>
        <p>
             <a href="javascript:void(0)" onclick="fazerSorteio();" class="acf-button button button-primary" title="Exportar">
               Sortear
             </a>
           </p>


      <?php
         
        
        
      }

}// FINAL DA CLASSE




/**
*  ------------------------------------------------------------------------------------------------
*
*
*   AJAX DA PÁGINA DE OPÇÕES
*
*
*  ------------------------------------------------------------------------------------------------
*/
function removerProdutoCotas() {
  
  $produto_id = intval( $_POST['produto'] );
  $cota = $_POST['cota'];
  
  
  $reservas = get_user_meta( $produto_id, "diogenesjunior.ti@gmail.com" );  

  $a = 0;
  $c = 0;
  while($a<count($reservas)):
     
     if($reservas[$a]!=""):

     	$atual = $reservas[$a];

        if(strstr($atual,$cota)):
			
			$nova_cota = str_replace($cota, "", $atual);
			
			update_user_meta( $produto_id, 'diogenesjunior.ti@gmail.com', $nova_cota, $atual );

			$prova[$c]["reservas"] = $atual;
			$prova[$c]["prova"] = $nova_cota; 
			$c++;

		else:

			// NEEEEEEEEXT
	
		endif;

     endif;
     

  	$a++;
  endwhile;

  $data = array('sucesso' => "200", 'cota' => $cota, 'prova' => $prova);

  $json_string = json_encode($data, JSON_PRETTY_PRINT);
 
  echo $json_string; 

  wp_die();

}

add_action('wp_ajax_remover_produto_cotas', 'removerProdutoCotas');
add_action( 'wp_ajax_nopriv_remover_produto_cotas', 'removerProdutoCotas' );







function filtrarProdutoCotas_v2() {
  
  $produto_id = intval( $_POST['produto'] );
  $versao = $_POST["versao"];

  $produto = wc_get_product( $produto_id );

  $titulo_produto = $produto->get_name();
  
  if($versao!=2):

            $reservas = get_user_meta( $produto_id, "diogenesjunior.ti@gmail.com" );  

            $a = 0;
            $c = 0;
            while($a<count($reservas)):
               
               if($reservas[$a]!=""):

               	$atual = $reservas[$a];

                  $quebra = explode(",",$atual);

                  $b = 0;
                  while($b<count($quebra)):

                  	if($quebra[$b]!="" && !in_array($quebra[$b],$valores)):
                      
                         $valores[$c] = $quebra[$b]; 
                         $c++;

                      endif;

                  	$b++;
                  endwhile;

               endif;
               

            	$a++;
            endwhile;


            $html = '<div><table class="table table-bordered"><thead><th colspan="2">'.$titulo_produto.'</th></thead><thead><th>Cota reservada</th><th>Ações</th></thead><tbody id="aquiSeHtmlValores"></tbody></table></div>';


            $data = array('sucesso' => "200", 'reservas' => $valores, 'html' => $html, 'titulo' => $titulo_produto);

            $json_string = json_encode($data, JSON_PRETTY_PRINT);
           
            echo $json_string; 

  endif;

  if($versao=="2"):
          
          $rifa = $produto_id;

          $pedidos = get_orders_ids_by_product_id($rifa);

          $a = 0;
          $b = 0;
          $valores = array();
          $array_cotas = array();
          $e = 0;

          while($a<count($pedidos)):

            $order = wc_get_order( $pedidos[$a] );

            $array_cotas[$b]["status"] = $order->get_status();

             if($array_cotas[$b]["status"]=="completed" || $array_cotas[$b]["status"]=="processing"):

                  $array_cotas[$b]["cotas_escolhidas"] = get_post_meta( $order->get_order_number(), 'billing_cotasescolhidas', true );

                  $b++;

             endif;
     
            $a++;
          endwhile;

          $a = 0;
          $total_r = 0;
          while($a<count($array_cotas)):

             $temp = explode(",",$array_cotas[$a]["cotas_escolhidas"]);
             $c = 0;
             while($c<count($temp)):

              $valores[$e] = $temp[$c]; $e++;

              $c++;
             endwhile;

            $a++;
          endwhile;


            $data = array('sucesso' => "200", 'reservas' => $valores);

            $json_string = json_encode($data, JSON_PRETTY_PRINT);
           
            echo $json_string; 


  endif;

  wp_die();

}

add_action('wp_ajax_filtrar_produto_cotas', 'filtrarProdutoCotas_v2');
add_action( 'wp_ajax_nopriv_filtrar_produto_cotas', 'filtrarProdutoCotas_v2' );









// RETORNAR DADOS PARA RIFA PRESENCIAL
function rifa_para_presencial() {
  
           $produto_id = intval( $_POST['produto'] );

           $pedidos = get_orders_ids_by_product_id($produto_id);

           $a = 0;

           // MONTAR O ARRAY COM NUMEROS DA RIFA (GERAL)
           $numero_de_cotas = get_field("numero_de_cotas",$produto_id);

           while($a<$numero_de_cotas):

            $listaTodosOsNumeros[$a] = coloque_zero($a,$produto_id);

            $a++;
           endwhile;

           $listaTodosOsNumerosZerado = $listaTodosOsNumeros;

           $a = 0;
           $b = 0;

           // MONTAR O ARRAY COM OS NUMEROS INDISPONIVEIS
           while($a<count($pedidos)):

             if(get_post_meta( $pedidos[$a], 'billing_cotasescolhidas', true )!=""):

                $temp = get_post_meta( $pedidos[$a], 'billing_cotasescolhidas', true );

                $temp2 = explode(",",$temp);

                $c = 0;
                while($c<count($temp2)):

                     if($temp2[$c]!=""):    
                   
                     $cotas[$b] = $temp2[$c];
                     $b++;

                   endif;

                  $c++;
                endwhile;

             endif;

             $a++;

           endwhile;

           // FILTRAR
           $novo_array_list = array_diff($listaTodosOsNumeros, $cotas);
           // $novo_array_list = lista de livres
           // $cotas = lista dos ocupados

           $a = 0;
           $b = 0;

           while($a<count($novo_array_list)):

              if(array_key_exists($a,$novo_array_list)){

                 $array_final[$b] = $novo_array_list[$a]; 
                 $b++;
              
              }
               
            $a++;
           endwhile;

           if($cotas==""):
             $cotas = array();
           endif;

           if($array_final==""):
             $array_final = $listaTodosOsNumerosZerado;
           endif;

           $data = array('sucesso'  => "200", 
                         'reservas' => $cotas, 
                         'livres'   => $array_final);

           $json_string = json_encode($data, JSON_PRETTY_PRINT);
                     
           echo $json_string; 

  wp_die();

}

add_action('wp_ajax_rifa_para_presencial', 'rifa_para_presencial');
add_action( 'wp_ajax_nopriv_rifa_para_presencial', 'rifa_para_presencial' );













// RETORNAR DADOS PARA RIFA PRESENCIAL
function rifa_para_presencial_criar() {
  
           $produto_id = intval( $_POST['produto'] );
           $quantidade = intval( $_POST['quantidade'] );
           $cotas = $_POST['cotas'];
           //$cotas = file_get_contents("php://input");
           
           $cotas = explode(",",$cotas); 

           shuffle($cotas);
           $a = 0;

           while($a<$quantidade):

             $cotas_reservadas = $cotas_reservadas . $cotas[$a].",";

             $a++;

           endwhile;

           
          global $woocommerce;

          $email = get_option('admin_email');
          $produto = $produto_id;
         
          $address = array(
              'first_name' => "Reservas",
              'last_name'  => "Rifas Presenciais",
              'email'      => $email
          );

          $order_data                        = array();
          $order_data[ 'post_type' ]         = 'shop_order';
          $order_data[ 'post_status' ]       = 'wc-' . apply_filters( 'woocommerce_default_order_status', 'rifa-presencial' );
          $order_data[ 'ping_status' ]       = 'closed';
          $order_data[ 'post_author' ]       = 1;
          $order_data[ 'post_password' ]     = uniqid( 'order_' );
          $order_data[ 'post_title' ]        = sprintf( __( 'Order &ndash; %s', 'woocommerce' ), strftime( _x( '%b %d, %Y @ %I:%M %p', 'Order date parsed by strftime', 'woocommerce' ), strtotime( $post_date ) ) );
          //$order_data[ 'post_parent' ]       = 12; // parent post id
          $order_data[ 'post_content' ]      = "";
          $order_data[ 'comment_status' ]    = "open";
          $order_data[ 'post_name' ]         = sanitize_title( sprintf( __( 'Order &ndash; %s', 'woocommerce' ), strftime( _x( '%b %d, %Y @ %I:%M %p', 'Order date parsed by strftime', 'woocommerce' ), strtotime( $post_date) ) ) );

          $order_id = wp_insert_post( apply_filters( 'woocommerce_new_order_data', $order_data ), true );

          $order = wc_get_order( $order_id );
          $order->add_product( wc_get_product( $produto ), $quantidade);

          $order->add_order_note( "Esse pedido foi criado para reservar números para Rifa Presencial" );
          
          // SALVAR HISTÓRICO
          $current_user = wp_get_current_user();
          $order->add_order_note( "Esse pedido foi criado pelo usuario: ".$current_user->user_email );

          $order->calculate_totals();
            
          add_post_meta( $order_id, 'billing_cotasescolhidas', $cotas_reservadas );

          $billing = array(
                 'first_name' => $primeiro_nome,
                 'last_name' => $sobrenome,
                 'email'      => $email,
                 'billing_cotasescolhidas' => $cotas_reservadas);
          
          $order->set_address( $billing, 'billing' );
          

          $data = array('sucesso'  => "200", 
                         'produto' => $produto_id,
                         'quantidade' => $quantidade, 
                         'livres'   => $cotas,
                         'cotas_reservadas' => $cotas_reservadas);

           $json_string = json_encode($data, JSON_PRETTY_PRINT);
                     
           echo $json_string; 

  wp_die();


}

add_action('wp_ajax_rifa_para_presencial_criar', 'rifa_para_presencial_criar');
add_action( 'wp_ajax_nopriv_rifa_para_presencial_criar', 'rifa_para_presencial_criar' );







function filtrarProdutoCotas() {
  
  $produto_id = intval( $_POST['produto'] );
  
  $produto = wc_get_product( $produto_id );

  $titulo_produto = $produto->get_name();
  
  $reservas = get_user_meta( $produto_id, "diogenesjunior.ti@gmail.com" );  

  $a = 0;
  $c = 0;
  while($a<count($reservas)):
     
     if($reservas[$a]!=""):

      $atual = $reservas[$a];

        $quebra = explode(",",$atual);

        $b = 0;
        while($b<count($quebra)):

          if($quebra[$b]!="" && !in_array($quebra[$b],$valores)):
            
               $valores[$c] = $quebra[$b]; 
               $c++;

            endif;

          $b++;
        endwhile;

     endif;
     

    $a++;
  endwhile;


  $html = '<div><table class="table table-bordered"><thead><th colspan="2">'.$titulo_produto.'</th></thead><thead><th>Cota reservada</th><th>Ações</th></thead><tbody id="aquiSeHtmlValores"></tbody></table></div>';


  $data = array('sucesso' => "200", 'reservas' => $valores, 'html' => $html, 'titulo' => $titulo_produto);

  $json_string = json_encode($data, JSON_PRETTY_PRINT);
 
  echo $json_string; 

  wp_die();

}

add_action('wp_ajax_filtrar_produto_cotas', 'filtrarProdutoCotas');
add_action( 'wp_ajax_nopriv_filtrar_produto_cotas', 'filtrarProdutoCotas' );





/**
*  ------------------------------------------------------------------------------------------------
*
*
*   INSERSÕES NO HTML
*
*
*  ------------------------------------------------------------------------------------------------
*/
add_action('wp_footer', 'modalRifaRodape'); 

function modalRifaRodape() { 
    echo '
       <div id="modalRifa">
          <div class="coluna-1" id="colunaUm">
               <p>Carregando...</p>
          </div>
          <div class="coluna-2" id="colunaDois">
               <img src="'.get_site_url().'/wp-content/plugins/plugin-rifa/images/loading.gif" style="width:32px;height:auto;" />
          </div>
       </div>
       
       <script type="text/javascript">
		  var homeUrlRifa = "'.get_site_url().'";
      var checkoutUrlPR = "'.wc_get_checkout_url().'";

     function coloque_zero(input0,globos){

            var input2 = 0;
            
            if(globos == 4 || globos == 0 || globos == ""){
                
              
                if(input0>=1000) return input0;
                
                if(input0<=9){ input2 = "000"+input0; }

                if(input0>=10 && input0 <= 99) input2 = "00"+input0;

                if(input0>=100 && input0 <= 999) input2 = "0" + input0;    

                return input2;

             }

             if(globos == 2){
                
                  if(input0<=9){ input2 = "0" + input0; return input2; }
                 return input0;
                
                

             }

             if(globos == 3){
                
               
                if(input0>=100) return input0;
                
                if(input0<=9){ input2 = "00" + input0; }
                
                

                if(input0>=10 && input0 <= 99) input2 = "0" + input0;

                if(input0>=100 && input0 <= 999) input2 = input0;    

                return input2;

             }


             if(globos == 5){
                
                if(input0>=10000) return input0;
                
                if(input0<=9){ input2 = "0000" + input0; }
                
                

                if(input0>=10 && input0 <= 99) input2 = "000" + input0;

                if(input0>=100 && input0 <= 999) input2 = "00" + input0;    

                if(input0>999 && input0 <= 9999) input2 = "0" + input0; 

                if(input0>9999 && input0 <= 99999) input2 = input0; 

                return input2;

             }

             if(globos == 6){
                
                if(input0>=100000) return input0;
                
                if(input0<=9){
                
                    input2 = "00000" + input0;
                
                }

                if(input0>=10 && input0 <= 99) input2 = "0000" + input0;

                if(input0>=100 && input0 <= 999) input2 = "000" + input0; 

                if(input0>999 && input0 <= 9999) input2 = "00" + input0; 

                if(input0>9999 && input0 <= 99999) input2 = "0" + input0;    

                return input2;

             }  

           }  


	   </script>
       '; 
}


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   SHORTCODES
*
*
*  ------------------------------------------------------------------------------------------------
*/

  function coloque_zero($input0,$id_produto){

    $globos = get_field("numero_globos",$id_produto);

    if($globos == 4 || $globos == 0 || $globos == ""){
        
        //if($input0==0) return "0000";
        if($input0>=1000) return $input0;
        
        if($input0<=9):
        
            $input2 = "000".$input0;
        
        endif;

        if($input0>=10 && $input0 <= 99) $input2 = "00".$input0;

        if($input0>=100 && $input0 <= 999) $input2 = "0".$input0;    

        return $input2;

     }

     if($globos == 2){
      if($input0<=9):
        
            $input2 = "0".$input0;
            return $input2;
        
        endif;
      return $input0;
     }
     if($globos == 3){
        
        //if($input0==0) return "0000";
        if($input0>=100) return $input0;
        
        if($input0<=9):
        
            $input2 = "00".$input0;
        
        endif;

        if($input0>=10 && $input0 <= 99) $input2 = "0".$input0;

        if($input0>=100 && $input0 <= 999) $input2 = $input0;    

        return $input2;

     }


     if($globos == 5){
        
        //if($input0==0) return "0000";
        if($input0>=10000) return $input0;
        
        if($input0<=9):
        
            $input2 = "0000".$input0;
        
        endif;

        if($input0>=10 && $input0 <= 99) $input2 = "000".$input0;

        if($input0>=100 && $input0 <= 999) $input2 = "00".$input0;    

        if($input0>999 && $input0 <= 9999) $input2 = "0".$input0; 

        if($input0>9999 && $input0 <= 99999) $input2 = $input0; 

        return $input2;

     }

     if($globos == 6){
        
        //if($input0==0) return "0000";
        if($input0>=100000) return $input0;
        
        if($input0<=9):
        
            $input2 = "00000".$input0;
        
        endif;

        if($input0>=10 && $input0 <= 99) $input2 = "0000".$input0;

        if($input0>=100 && $input0 <= 999) $input2 = "000".$input0; 

        if($input0>999 && $input0 <= 9999) $input2 = "00".$input0; 

        if($input0>9999 && $input0 <= 99999) $input2 = "0".$input0;    

        return $input2;

     }





  }


function limparArrayCotas($array){
   
   $a = 0;
   $p = 0;
   $posicoes = array();

   while($a<count($array)):
    
    if($array[$a]!="" && !in_array($array[$a],$posicoes)){
       $dado = str_replace(",", ", ", $array[$a]);
       $saida = $saida . $dado;

       $posicoes[$p] = $array[$a];
       $p++;

    }

    $a++;
   endwhile;

   return $saida;

}


function funcao_cotasrifa( $atts ) { 

	$rifa = $atts['rifa'];
  
  if($rifa==""){ $rifa = $atts["rifa"]; }

  $exibircompradores = $atts['exibircompradores'];
  $modelojuntas = $atts["modelojuntas"];
    
    $html = '

         <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />

         <div class="cotas-disponiveis" id="cotasDisponiveisSelector">

             <style>

                .cotas-disponiveis .form-check{
                  border: 1px solid ' . get_field("cor_do_borda_cota_antes_selecao", $rifa) . ' !important;
                }

                .cotas-disponiveis .form-check input:checked + label{
                  background: ' . get_field("cor_de_fundo_selecao", $rifa) . ' !important;
                }
                
                #modalRifa .coluna-1 span{
                  background: ' . get_field("cor_de_fundo_selecao_modal_rodape", $rifa) . ' !important;
                }

                #modalRifa .coluna-2 h3 a{
                  color: ' . get_field("cor_do_texto_btn_finalizar_compra") . '  !important;
                  background: ' . get_field("cor_de_fundo_btn_finalizar_compra", $rifa) . ' !important;
              }

                .pcss3t > input:checked + label{
                    border-bottom: 2px solid ' . get_field("cor_do_borda_abas_livres_reservadas",$rifa) . ' !important;
              }

             </style>
             
    ';


    $args = array( 'post_type' => 'product', 
                         'p' => $rifa, 

    );

    $html_prova = "";
    $new_vet = array();
    $r = 0;

    $loop = new WP_Query( $args );
    while ( $loop->have_posts() ) : $loop->the_post(); 
                          
              $cotas = get_field("numero_de_cotas");

              $reservas = get_user_meta( get_the_ID(), "diogenesjunior.ti@gmail.com");

              //print_r($reservas);

              $participantes = get_users(array(
                  'meta_key'     => get_the_ID(),
              ));
                            
              
              $a = 0;
              while($a<count($reservas)):
                
                 $estado = explode(",",$reservas[$a]);
                 

                 $b = 0;
                 while($b<count($estado)):
                    
                    /*
                    if($estado[$b]!=""){

                    	$new_vet[$r] = $estado[$b]; 
                        $r++;
                        echo "NEW VET: ".$new_vet[$r]."<br>";

                    }
                    */
                    
                    //echo "($a)($b)(".$reservas[$a].")", $estado[$b],"<br>";

                    if($estado[$b]!=""){
                    	$new_vet[$r] = $estado[$b]; $r++;
                    }

                 	//$html_prova = $html_prova.$estado[$b]."#";

                 	$b++;
                 endwhile;

              	$a++;
              endwhile;
             


              
              // **************** COTAS DISPONÍVEIS
              $negado = "não";
              $l = 0;
              $html_d = "";
              $total_d = 0;
              //$l--;

              // **************** COTAS RESERVADAS
              $negado = "não";
              $html_r = "";
              $total_r = 0;
              $l = 0;
              //$l--;

              while($l<$cotas):

                            //$a = $l + 1;
                            $a = $l;
                          

				              if( count(array_keys($new_vet, coloque_zero($a,$rifa) )) == 0):

				              	    $total_d++;

		                            $html_d = $html_d . '

						                <div class="form-check">
						                  <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="'.coloque_zero($a,$rifa).'" id="cota'.coloque_zero($a,$rifa).'">
						                  <label class="form-check-label label-um" for="cota'.coloque_zero($a,$rifa).'">
						                    '.coloque_zero($a,$rifa).'
						                  </label>
						                </div>

						            ';

				              endif;

                        if( count(array_keys($new_vet, coloque_zero($a,$rifa) )) > 0):

                            $total_r++;

                                $html_r = $html_r . '

                            <div class="form-check">
                              <input class="form-check-input" type="checkbox" name="cotas_reservadas" id="cotaReservada'.coloque_zero($a,$rifa).'" disabled>
                              <label class="form-check-label label-um" disabled for="cotaReservada'.coloque_zero($a,$rifa).'">
                                '.coloque_zero($a,$rifa).'
                              </label>
                            </div>

                        ';

                      endif;

                      $negado = "não";

				          

              $l++;
              endwhile;
              



              
/*
              while($l<$cotas):

                            $a = $l;

                          

				            

              $l++;
              endwhile;
              */

              // ************************** COTAS TODAS JUNTAS
              if($modelojuntas=="sim"){

                      $negado = "não";
                      $html_r = "";
                      $total_r = 0;
                      $l = 0;
                      //$l--;
                      $negado = "não";
                      $html_d = "";
                      $total_d = 0;

                      while($l<$cotas):

                                    $a = $l;

                                  

                              if( count(array_keys($new_vet, coloque_zero($a,$rifa) )) > 0):

                                    $total_r++;

                                        $html_r = $html_r . '

                                    <div class="form-check">
                                      <input class="form-check-input" type="checkbox" name="cotas_reservadas" id="cotaReservada'.coloque_zero($a,$rifa).'" disabled>
                                      <label class="form-check-label label-um label-desativado" disabled for="cotaReservada'.coloque_zero($a,$rifa).'" style="background:'.get_field("cor_reserva_juntas",$rifa).' !important;color:'.get_field("cor_texto_juntas",$rifa).' !important;">
                                        '.coloque_zero($a,$rifa).'
                                      </label>
                                    </div>

                                ';
                              else:

                                 $total_d++;

                                $html_r = $html_r . '

                                      <div class="form-check">
                                        <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="'.coloque_zero($a,$rifa).'" id="cota'.coloque_zero($a,$rifa).'">
                                        <label class="form-check-label label-um" for="cota'.coloque_zero($a,$rifa).'">
                                          '.coloque_zero($a,$rifa).'
                                        </label>
                                      </div>

                                  ';



                              endif;

                              $negado = "não";

                      $l++;
                      endwhile;

                      $html = $html . $html_r;

              }






              // ************************** EXIBIR COMPRADORES
              if($exibircompradores!="sim" && $modelojuntas!="sim"){

                  $html = $html . '

                         <!-- ABAS -->
                         <div class="page-tabs">
                            <div class="pcss3t pcss3t-height-auto">
                                 
                                   <input type="radio" name="pcss3t" checked id="tab1" class="tab-content-first">
                                   <label for="tab1">LIVRES ('.$total_d.')</label>
                                                                                        
                                   <input type="radio" name="pcss3t"  id="tab2" class="tab-content-2">
                                   <label for="tab2">RESERVADAS ('.$total_r.')</label>

                                 <ul style="padding-left:0px;margin-left:0px;">
                                                                                             
                                   <!-- ABA UM -->
                                   <li class="tab-content tab-content-first" style="padding-left:0px !important;padding-right:0px !important;">
                                     '.$html_d.'
                                   </li>
                                   <!-- ABA UM -->

                                   <!-- ABA DOIS -->
                                   <li class="tab-content tab-content-2" style="padding-left:0px !important;padding-right:0px !important;">
                                    '.$html_r.'
                                   </li>
                                   <!-- ABA DOIS -->

                                 </ul>

                            </div>
                          </div>
                          <!-- ABAS -->
                  ';

              }

              if($exibircompradores=="sim"){

                      $total_p = 0;
                      $html_p = "";

                      $anterior = "XXX";
                      $atual = "XXX";


                      foreach ( $participantes as $user ) {

                          $temp = explode("@", esc_html( $user->user_email));
                          $sufixo = substr($temp[1], 4);
                          $email = $temp[0]."@****".$sufixo;  

                          $html_temp = '<tr>
                             <td>' . esc_html( $user->display_name ) . '</td>
                             <td class="email_rifa">' . esc_html( $email ) . '</td> 
                             <td>'. limparArrayCotas(get_user_meta( $user->ID, $rifa, false )) .'</td>
                          </tr>';

                          $atual = $html_temp;

                          if($anterior!=$atual){
                            $html_p = $html_p . $html_temp;
                            $total_p++;
                            $anterior = $atual;
                          }
                      }



                      $html = $html . '

                           <!-- ABAS -->
                           <div class="page-tabs">
                              <div class="pcss3t pcss3t-height-auto">
                                   
                                     <input type="radio" name="pcss3t" checked id="tab1" class="tab-content-first">
                                     <label for="tab1">LIVRES ('.$total_d.')</label>
                                                                                          
                                     <input type="radio" name="pcss3t"  id="tab2" class="tab-content-2">
                                     <label for="tab2">RESERVADAS ('.$total_r.')</label>

                                     <input type="radio" name="pcss3t"  id="tab3" class="tab-content-3">
                                     <label for="tab3">PARTICIPANTES ('.$total_p.')</label>

                                   <ul style="padding-left:0px;margin-left:0px;">
                                                                                               
                                     <!-- ABA UM -->
                                     <li class="tab-content tab-content-first" style="padding-left:0px !important;padding-right:0px !important;">
                                       '.$html_d.'
                                     </li>
                                     <!-- ABA UM -->

                                     <!-- ABA DOIS -->
                                     <li class="tab-content tab-content-2" style="padding-left:0px !important;padding-right:0px !important;">
                                      '.$html_r.'
                                     </li>
                                     <!-- ABA DOIS -->

                                     <!-- ABA TRÊS -->
                                     <li class="tab-content tab-content-3" style="padding-left:0px !important;padding-right:0px !important;">

                                     <table class="table table-bordered">

                                        <thead>
                                            <th>Nome</th>
                                            <th class="email_rifa">E-mail</th>
                                            <th>Cotas escolhidas</th>
                                        </thead>

                                      '.$html_p.'

                                      </table>
                                      <p style="font-size:12px;"><i>A reserva da cota pelo usuário está sujeito a confirmação do pagamento.</i></p>
                                     </li>
                                     <!-- ABA TRÊS -->

                                   </ul>

                              </div>
                            </div>
                            <!-- ABAS -->
                    ';


                    if(get_field("exibir_email")=="n"){
                       $html = $html . "

                          <style>
                              .email_rifa{
                                display: none !important;
                              }
                          </style>

                       ";
                    }

              }




    endwhile; 
    wp_reset_query(); 
	

	$html = $html . '</div><br>' . $html_prova;
    
    //echo "ESSE? ";
	//print_r($new_vet);

    
    return $html;
		
}

add_shortcode('exibir_cotas', 'funcao_cotasrifa');










function funcao_metarifa( $atts ) { 

  $rifa = $atts['rifa'];
      
    $args = array( 'post_type' => 'product', 
                           'p' => $rifa, 

    );

    $html_prova = "";
    $new_vet = array();
    $r = 0;

    $loop = new WP_Query( $args );
    while ( $loop->have_posts() ) : $loop->the_post(); 
                          
              $cotas = get_field("numero_de_cotas");

              $reservas = get_user_meta( get_the_ID(), "diogenesjunior.ti@gmail.com");

              //print_r($reservas);

              $participantes = get_users(array(
                  'meta_key'     => get_the_ID(),
              ));
                            
              
              $a = 0;
              while($a<count($reservas)):
                
                 $estado = explode(",",$reservas[$a]);
                 

                 $b = 0;
                 while($b<count($estado)):
                    
                    /*
                    if($estado[$b]!=""){

                      $new_vet[$r] = $estado[$b]; 
                        $r++;
                        echo "NEW VET: ".$new_vet[$r]."<br>";

                    }
                    */
                    
                    //echo "($a)($b)(".$reservas[$a].")", $estado[$b],"<br>";

                    if($estado[$b]!=""){
                      $new_vet[$r] = $estado[$b]; $r++;
                    }

                  //$html_prova = $html_prova.$estado[$b]."#";

                  $b++;
                 endwhile;

                $a++;
              endwhile;
             


              
              // **************** COTAS DISPONÍVEIS
              $negado = "não";
              $l = 0;
              $html_d = "";
              $total_d = 0;
              //$l--;

              while($l<$cotas):

                            $a = $l + 1;

                          

                      if( count(array_keys($new_vet, coloque_zero($a,$rifa) )) == 0):

                            $total_d++;

                           

                      endif;

                  

              $l++;
              endwhile;
              



              // **************** COTAS RESERVADAS
              $negado = "não";
              $html_r = "";
              $total_r = 0;
              $l = 0;
              //$l--;

              while($l<$cotas):

                            $a = $l;

                          

                      if( count(array_keys($new_vet, coloque_zero($a,$rifa) )) > 0):

                            $total_r++;

                         

                      endif;

                      $negado = "não";

              $l++;
              endwhile;
              


    endwhile; 
    wp_reset_query(); 
    

    $x = $total_r / $cotas;
    $y = $x * 100;

    // Y GUARDA A % PREENCHIDA

    $html = '

      <div class="rifa-barra-de-progresso">
          <div class="quantidade-ate-meta" style="width:'.$y.'% !important">&nbsp;</div>
      </div>
      <p class="descricao-meta-rifa">
          '.number_format($y,2,".",",").'% da meta alcançada
      </p>

    ';

    return $html;
    
}

add_shortcode('meta_rifa', 'funcao_metarifa');





function funcao_metarifa_v2( $atts ) { 

    $rifa = $atts['rifa'];

    $cotas = get_field("numero_de_cotas",$rifa);

    $pedidos = get_orders_ids_by_product_id($rifa);

      $a = 0;
      $b = 0;
      $array_cotas = array();


      while($a<count($pedidos)):

        $order = wc_get_order( $pedidos[$a] );

        $array_cotas[$b]["status"] = $order->get_status();

         if($array_cotas[$b]["status"]=="completed" || $array_cotas[$b]["status"]=="processing"):

              $array_cotas[$b]["cotas_escolhidas"] = get_post_meta( $order->get_order_number(), 'billing_cotasescolhidas', true );

              $b++;

         endif;
 
        $a++;
      endwhile;

      $a = 0;
      $super = array();
      $total_r = 0;
      $c = 0;
      while($a<count($array_cotas)):

         $temp = explode(",",$array_cotas[$a]["cotas_escolhidas"]);
         //$total_r = $total_r + count($temp);

         $b = 0;
         while($b<count($temp)):

            if($temp[$b]!="") $super[$c] = $temp[$b];

            $b++;
            $c++;

         endwhile;

        $a++;
      endwhile;

    $total_r = count(array_unique($super));  

    $x = $total_r / $cotas;
    $y = $x * 100;
    $super = array_unique($super);
    //print_r($super);
    // Y GUARDA A % PREENCHIDA
    $html = '

      <div class="rifa-barra-de-progresso" data-prova-real="'.$total_r.'" data-prova-two="'.count($array_cotas).'">
          <div class="quantidade-ate-meta" style="width:'.$y.'% !important">&nbsp;</div>
      </div>
      <p class="descricao-meta-rifa">
          '.number_format($y,2,".",",").'% da meta alcançada
      </p>

    ';

    return $html;
    
}

add_shortcode('meta_rifa_v2', 'funcao_metarifa_v2');









/**
*  ------------------------------------------------------------------------------------------------
*
*
*   SALVAR NO CARRINHO DE COMPRAS
*
*
*  ------------------------------------------------------------------------------------------------
*/
function salvar_carrinho() {
  
      $produto_id = intval( $_POST['id'] );
      $quantidade = intval( $_POST['qtd'] );
      
      global $woocommerce;
      
      $num_max_cotas_por_cliente = get_field("num_maximo_reservas",$produto_id);
      $num_mix_cotas_por_cliente = get_field("num_minimo_reservas",$produto_id);

      $msg_num_maximo_reservas = get_field("msg_num_maximo_reservas",$produto_id);
      $msg_num_minimo_reservas = get_field("msg_num_minimo_reservas",$produto_id);

      $msg_explicativa_num_maximo = get_field("msg_explicativa_num_maximo",$produto_id);
      $msg_explicativa_num_minimo = get_field("msg_explicativa_num_minimo",$produto_id);
      
      $texto_btn_finalizar_compra = get_field("texto_btn_finalizar_compra",$produto_id);
      $currency = get_woocommerce_currency_symbol();


      $aprovacao = "0";
      $erros     = "0";

      if($quantidade <= $num_max_cotas_por_cliente || 
         $num_max_cotas_por_cliente == 0 || 
         $num_max_cotas_por_cliente == NULL):

        $aprovacao = "1";

      else:

        $erros = "XXX";

      endif;

      if($quantidade >= $num_mix_cotas_por_cliente || 
         $num_mix_cotas_por_cliente == 0 || 
         $num_mix_cotas_por_cliente == NULL):

        $aprovacao = "1";

      else:

        $erros = "YYY";

      endif;

      if($aprovacao=="1" && $erros == "0"):

          // PRIMEIRO LIMPAMOS O CARRINHO
          $woocommerce->cart->empty_cart();

          // DEPOIS ADICIONADOS O PRODUTO E A QUANTIDADE NO CARRINHO
          $woocommerce->cart->add_to_cart($produto_id,$quantidade);
                          
          // DEPOIS RETORNAMOS O TOTAL DO CARRINHO
          $data = array('sucesso' => "200", 'valor' => WC()->cart->total, 'texto_btn_finalizar_compra' => $texto_btn_finalizar_compra, 'currency' => $currency);

          $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
          echo $json_string; 
          
      else:

        $data = array('sucesso' => "400", 'erros' => $erros, 'texto_btn_finalizar_compra' => $texto_btn_finalizar_compra, 'currency' => $currency, 'msg_num_maximo_reservas' => $msg_num_maximo_reservas, 'msg_num_minimo_reservas' => $msg_num_minimo_reservas, 'msg_explicativa_num_maximo' => $msg_explicativa_num_maximo, 'msg_explicativa_num_minimo' => $msg_explicativa_num_minimo);




        $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
        echo $json_string;

      endif;

      wp_die();

}

add_action('wp_ajax_salvar_carrinho', 'salvar_carrinho');
add_action( 'wp_ajax_nopriv_salvar_carrinho', 'salvar_carrinho' );





/**
*  ------------------------------------------------------------------------------------------------
*
*
*   EXIBIR OS PRODUTOS COMPRADOS NAS COLUNAS DO ADMIN
*
*
*  ------------------------------------------------------------------------------------------------
*/
add_filter('manage_edit-shop_order_columns', 'misha_order_items_column' );
function misha_order_items_column( $order_columns ) {
    $order_columns['order_products'] = "Rifa";
    return $order_columns;
}
 
add_action( 'manage_shop_order_posts_custom_column' , 'misha_order_items_column_cnt' );
function misha_order_items_column_cnt( $colname ) {
	global $the_order; // the global order object
 
 	if( $colname == 'order_products' ) {
 
		// get items from the order global object
		$order_items = $the_order->get_items();
 
		if ( !is_wp_error( $order_items ) ) {
			foreach( $order_items as $order_item ) {
 
 				echo $order_item['quantity'] .' × <a href="' . admin_url('post.php?post=' . $order_item['product_id'] . '&action=edit' ) . '">'. $order_item['name'] .'</a><br />';
				// you can also use $order_item->variation_id parameter
				// by the way, $order_item['name'] will display variation name too
				$cotas = get_post_meta( $the_order->get_order_number(), 'billing_cotasescolhidas', true );
				echo "<br>Cotas: ".$cotas;
 
			}
		}
 
	}
 
}

/**
*  ------------------------------------------------------------------------------------------------
*
*
*   SALVAR AS RESERVAS DO USUARIO NO BANCO DE DADOS (DEIXA-LAS INDISPONIVEIS PARA OUTROAS COMPRAS)
*
*
*  ------------------------------------------------------------------------------------------------
*/

//woocommerce_after_order_object_save
//woocommerce_new_order
//add_action( 'woocommerce_order_details_before_order_table', 'rifatrusted_shops_thankyou', 15, 1 );
add_action( 'woocommerce_after_order_object_save', 'rifatrusted_shops_thankyou', 15, 1 );
function rifatrusted_shops_thankyou( $order ) {

   $id_comprador = $order->user_id;
   $items = $order->get_items(); 
	foreach ( $items as $item ) {

	        $product_name = $item->get_name();
	        $product_id = $item->get_product_id();
	        $qtd = $qtd + $item->get_quantity();
	        //echo "<br>CHAVE: ".$product_id;
	}

	$reservas = get_post_meta( $order->get_order_number(), 'billing_cotasescolhidas', true );
  $num_celular = get_post_meta( $order->get_order_number(), 'billing_cellphone', true );
  $num_fixo = get_post_meta( $order->get_order_number(), 'billing_phone', true );

    // ID DO PRODUTO, ID DO USUARIO, RESERVAS (SALVAR AS RESERVAS DE UM CLIENTE)
	add_user_meta( $product_id, "diogenesjunior.ti@gmail.com", $reservas);
    
    // ID FAKE, ID DO PRODUTO, RESERVAS (SALVAR DISPONIBILDIADES)
	add_user_meta($id_comprador, $product_id, $reservas);


}


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   BUSCAR RESERVAS FEITAS
*
*
*  ------------------------------------------------------------------------------------------------
*/
function funcao_buscar_reservas( $atts ) { 

	$id_produto = $atts['produto'];
  $rifa = $atts['produto'];
	$estilo = $atts['estilo-input'];
	$estilo_btn = $atts['estilo-btn'];
    

    
    $html = '
       
       <form method="post" action="">
           <input type="email" name="emailConsultaBuscarReservas" class="form-control" placeholder="Digite seu e-mail" required style="border:1px solid #ccc !important;height:38px;max-width:300px;border:none;box-shadow:none;'.$estilo.'" />
          <button type="submit" style="font-weight:bold;'.$estilo_btn.'" class="btn btn-primary">Buscar</button>
       </form>

    '; 

    if($_POST["emailConsultaBuscarReservas"]):
          
          $usuarios = get_user_by( 'email', $_POST["emailConsultaBuscarReservas"] );

          if($usuarios!=""):

		          $id = $usuarios->ID;

		          $html = $html.'
		             
		             <p style="padding-top:12px;">Usuário: '.$_POST["emailConsultaBuscarReservas"].'</p>
		             <p><b>Suas cotas:</b></p><div class="cotas-disponiveis">

		          ';

		          $reservas = get_user_meta( $id, $id_produto);

          endif;

          $a = 0;

       
        
  $html = $html."<div>";

          while($a<count($reservas)):

          	$temp = explode(",",$reservas[$a]);
          	$c = 0;

            $anterior = "X";
            $atual    = "Y";
            $i = 1;
            $impressos[0] = "pluginrifa";

          	while($c<count($temp)):

          		                if($temp[$c]!=""):

                                $atual = $temp[$c];

                                

                                if($atual!=$anterior && !in_array($temp[$c], $impressos)):

                                  $impressos[$i] = $temp[$c];
                                $i++;

          		                    $html = $html . '

						                <div class="form-check">
						                  <input class="form-check-input" type="checkbox" name="cotas" value="'.$temp[$c].'" id="cota'.$temp[$c].'">
						                  <label class="form-check-label label-um" for="cota'.$temp[$c].'" style="background:'.get_field("cor_reserva_juntas",$rifa).' !important;color:'.get_field("cor_texto_juntas",$rifa).' !important;">
						                    '.$temp[$c].'
						                  </label>
						                </div>

						            ';

                          $anterior = $temp[$c];


                         endif;

						        endif;

          		$c++;
          	endwhile;

          	

          	$a++;
          endwhile;

          $html = $html . '</div><br clear="both">';

    endif;
    
    //
    //add_user_meta( "1111", "diogenesjunior.ti@gmail.com", "12,13,14,15" );
    //$html = get_user_meta( "1111", "diogenesjunior.ti@gmail.com" );

    //return print_r($html);



    return $html;
		
}

add_shortcode('buscar_reservas', 'funcao_buscar_reservas');


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   PESQUISA DE COTAS
*
*
*  ------------------------------------------------------------------------------------------------
*/
function funcao_pesquisa_cotas($atts) { 
    
    $estilo = $atts['estilo-input'];
	  $estilo_btn = $atts['estilo-btn'];
	  
    
    $html = '
       
                                     <!-- BUSCA DE COTAS -->
                                     <div class="busca-avulsa">
                                            
                                         <input type="text" placeholder="Pesquise por um número" onkeyup="filtrotabela();" id="filtroTabela" class="form-control" style="border:1px solid #ccc !important;height:38px;box-shadow:none;max-width:300px;'.$estilo.'">

                                         <button type="submit" style="font-weight:bold;'.$estilo_btn.'" class="btn btn-primary">Buscar</button>
                                           
                                     </div>
                                     <!-- BUSCA AVULSA -->


    '; 

    


    return $html;
		
}

add_shortcode('pesquisa_cotas', 'funcao_pesquisa_cotas');



/**
*  ------------------------------------------------------------------------------------------------
*
*
*   RESTABELECER UMA COTA COMPRADA QUANDO O PEDIDO FOR CANCELADO
*
*
*  ------------------------------------------------------------------------------------------------
*/
add_action( 'woocommerce_order_status_cancelled', 'cancelar_reserva_cota', 21, 1 );

function cancelar_reserva_cota( $order_id ) {

    $order = new WC_Order( $order_id );     

    $id_comprador = $order->user_id;
    $items = $order->get_items(); 
	
	foreach ( $items as $item ) {

	        $product_name = $item->get_name();
	        $product_id = $item->get_product_id();
	        $qtd = $qtd + $item->get_quantity();
	        
	}

	$reservas = get_post_meta( $order->get_order_number(), 'billing_cotasescolhidas', true );

    // ID DO PRODUTO, ID DO USUARIO, RESERVAS (SALVAR AS RESERVAS DE UM CLIENTE)
	delete_user_meta( $product_id, "diogenesjunior.ti@gmail.com", $reservas);
    
    // ID FAKE, ID DO PRODUTO, RESERVAS (SALVAR DISPONIBILDIADES)
	delete_user_meta($id_comprador, $product_id, $reservas); 
}




/**
*  ------------------------------------------------------------------------------------------------
*
*
*   V2
*
*
*  ------------------------------------------------------------------------------------------------
*/
function funcao_cotasrifa_v2( $atts ) { 

  $rifa = $atts['rifa'];
  
  if($rifa==""){ $rifa = $atts["rifa"]; }

  $exibircompradores = $atts['exibircompradores'];
  $modelojuntas = $atts["modelojuntas"];
  $modelo4 = $atts["modelo4"];
  $fake = $atts["fake"];

    if($fake=="sim"):

        return '

           <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />
           <script type="text/javascript">

                 console.log("Carregando rifa....");
                 var rifaFake = Array();
                 var rifaFakeProc = Array();

                 Array.prototype.remove = function() {
                      var what, a = arguments, L = a.length, ax;
                      while (L && this.length) {
                          what = a[--L];
                          while ((ax = this.indexOf(what)) !== -1) {
                              this.splice(ax, 1);
                          }
                      }
                      return this;
                  };

                 ;(function ( $, window, document, undefined ) {

                      var ajaxurl = "'.get_site_url().'/wp-admin/admin-ajax.php";
  
                      let xhr = new XMLHttpRequest();
                       
                      xhr.open("POST", ajaxurl,true);
                      xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

                      var params = "action=exibir_cotas_ajax_v2&id='.$rifa.'";
                      
                      // INICIO AJAX VANILLA
                      xhr.onreadystatechange = () => {

                        if(xhr.readyState == 4) {

                              if(xhr.status == 200) {

                                  //console.log(JSON.parse(xhr.responseText));

                                  var dados = JSON.parse(xhr.responseText);

                                  // IMPRIMIR OS NÚMEROS
                                  var htmlCotasInicio = "";
                                  let pFprogresso = 0;
                                  let htmlDenovo = "";

                                  for(let i = 0;i<dados.cotas;i++){

                                      
                                      setTimeout(function() { 

                                            
                                            /*
                                            jQuery("#cotasrifa_v2").append(`

                                                <div class="form-check" id="fc${coloque_zero(i,dados.globos)}">
                                                <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                  ${coloque_zero(i,dados.globos)}
                                                </label>
                                              </div>

                                            `);
                                            */

                                            if(i==dados.cotas-1){ conferirNumeros(); }
                                            

                                            htmlDenovo = htmlDenovo + `

                                               <div class="form-check" id="fc${coloque_zero(i,dados.globos)}">
                                                  <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                  <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                    ${coloque_zero(i,dados.globos)}
                                                  </label>
                                                </div>

                                        `;

                                        rifaFake.push(coloque_zero(i,dados.globos));

                                        }, 0);

                                  }

                                 

                                  function conferirNumeros(){


                                        var numeros_escolhidos = "";
                                        jQuery("#pFprogresso").remove();

                                          // ELIMINAR AS COTAS JÁ RESERVADAS
                                          for(var i = 0;i<dados.participantes.length;i++){

                                              //console.log("DEPURAÇÃO 2: "+i);

                                              numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                              var numero_isolado;
                                              var a = 0;
                                              while(a<numeros_escolhidos.length){

                                                numero_isolado = numeros_escolhidos[a];

                                                // REMOVER O NÚMERO JÁ RESERVADO
                                                //jQuery(`#fc${numero_isolado}`).hide(0);

                                                rifaFakeProc.push(numero_isolado);
                                                //rifaFake.remove(parseInt(numero_isolado));

                                                if(numero_isolado[0]==0){
                                                  rifaFake.remove(numero_isolado);
                                                }else{
                                                  rifaFake.remove(parseInt(numero_isolado));
                                                }

                                                //console.log("TENTANDO REMOVER: "+"#fc"+numero_isolado);

                                                a++;
                                              
                                              }

                                          }

                                  }
                               
                              }
                                                       
                        }

                    }; // FINAL AJAX VANILLA

                    /* EXECUTA */
                    xhr.send(params);

                 })( jQuery, window, document );

           </script>

           ';

    endif;


    if($exibircompradores=="" && $modelojuntas=="" && $fake=="" && $modelo4==""): 

        $estilo_cota = "";

        if(get_field("tipo_de_cota",$rifa)=="Cota redonda"):

            $estilo_cota = '

                .form-check-label {
                    margin-bottom: 0;
                    border-radius: 100% !important;
                    height: 53px !important;
                }
                .cotas-disponiveis .form-check {
                    border-radius: 100% !important;
                }


            ';

        endif;

        return '

           <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />

           <style>

                .cotas-disponiveis .form-check{
                  border: 1px solid ' . get_field("cor_do_borda_cota_antes_selecao", $rifa) . ' !important;
                }

                .cotas-disponiveis .form-check input:checked + label{
                  background: ' . get_field("cor_de_fundo_selecao", $rifa) . ' !important;
                }
                
                #modalRifa .coluna-1 span{
                  background: ' . get_field("cor_de_fundo_selecao_modal_rodape", $rifa) . ' !important;
                }

                #modalRifa .coluna-2 h3 a{
                  color: ' . get_field("cor_do_texto_btn_finalizar_compra") . '  !important;
                  background: ' . get_field("cor_de_fundo_btn_finalizar_compra", $rifa) . ' !important;
              }

                .pcss3t > input:checked + label{
                    border-bottom: 2px solid ' . get_field("cor_do_borda_abas_livres_reservadas",$rifa) . ' !important;
              }

              '.$estilo_cota.'

             </style>




           <div class="cotas-disponiveis" id="cotasrifa_v2">

           <div id="pFprogresso" style="position:absolute;display:block;width:100%;height:100%;background:rgba(255,255,255,0.85);padding-top:30px;text-align:center;z-index:999;color:#000 !important;"><d>Carregando números</d> <span></span>
                 <div class="barra-progresso-carregamento" style="position:relative;display:block;width:200px;height:11px;background:#f2f2f2;margin-left: auto;margin-right: auto;margin-top: 12px;border-radius: 14px;">
                  <div class="thumb-barra" style="height:100%;position:relative;display:block;background:#62C75D;width:0;border-radius: 14px;"></div>
                 </div>
            </div>
            
           </div>
           <script type="text/javascript">

                 console.log("Carregando rifa....");

                 ;(function ( $, window, document, undefined ) {

                      var ajaxurl = "'.get_site_url().'/wp-admin/admin-ajax.php";
  
                      let xhr = new XMLHttpRequest();
                       
                      xhr.open("POST", ajaxurl,true);
                      xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

                      var params = "action=exibir_cotas_ajax_v2&id='.$rifa.'";
                      
                      // INICIO AJAX VANILLA
                      xhr.onreadystatechange = () => {

                        if(xhr.readyState == 4) {

                              if(xhr.status == 200) {

                                  //console.log(JSON.parse(xhr.responseText));

                                  var dados = JSON.parse(xhr.responseText);

                                  // IMPRIMIR OS NÚMEROS
                                  var htmlCotasInicio = "";
                                  let pFprogresso = 0;
                                  let htmlDenovo = "";

                                  for(let i = 0;i<dados.cotas;i++){

                                      

                                      setTimeout(function() { 

                                            pFprogresso = i / dados.cotas * 100;

                                            jQuery("#pFprogresso span").html(`${pFprogresso.toFixed(2)}%`);
                                            jQuery(".thumb-barra").css("width",`${pFprogresso.toFixed(2)}%`);

                                            if(pFprogresso>50){
                                               jQuery("#pFprogresso d").html(`Consultando reservas`);
                                            }
                                            if(pFprogresso>70){
                                               jQuery("#pFprogresso d").html(`Consultando pagamentos`);
                                            }

                                            if(pFprogresso>90){
                                               jQuery("#pFprogresso d").html(`Quase terminando... `);
                                            }

                                            /*
                                            jQuery("#cotasrifa_v2").append(`

                                                <div class="form-check" id="fc${coloque_zero(i,dados.globos)}">
                                                <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                  ${coloque_zero(i,dados.globos)}
                                                </label>
                                              </div>

                                            `);

                                            if(i==dados.cotas-1){ conferirNumeros(); }
                                            */

                                            htmlDenovo = htmlDenovo + `

                                               <div class="form-check" id="fc${coloque_zero(i,dados.globos)}">
                                                  <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                  <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                    ${coloque_zero(i,dados.globos)}
                                                  </label>
                                                </div>

                                        `;

                                        }, 0);

                                  }

                                  setTimeout(function() { 

                                    document.getElementById("cotasrifa_v2").innerHTML = `${htmlDenovo}`;

                                    conferirNumeros();
                                    
                                  }, 2500);

                                  function conferirNumeros(){


                                        var numeros_escolhidos = "";
                                        jQuery("#pFprogresso").remove();

                                          // ELIMINAR AS COTAS JÁ RESERVADAS
                                          for(var i = 0;i<dados.participantes.length;i++){

                                              console.log("DEPURAÇÃO 2: "+i);

                                              numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                              var numero_isolado;
                                              var a = 0;
                                              while(a<numeros_escolhidos.length){

                                                numero_isolado = numeros_escolhidos[a];

                                                // REMOVER O NÚMERO JÁ RESERVADO
                                                jQuery(`#fc${numero_isolado}`).hide(0);

                                                //console.log("TENTANDO REMOVER: "+"#fc"+numero_isolado);

                                                a++;
                                              
                                              }

                                          }

                                          if (typeof reservasTemporarias === "function") { 
                                              reservasTemporarias();
                                          }else{
                                              console.log("Nenhuma extensão instalada");
                                          }

                                          setTimeout(function(){ 

                                            preencherNumerosPreSelecionados(); 

                                          }, 1000);

                                  }


                                  
                               
                              }
                                                       
                        }

                    }; // FINAL AJAX VANILLA

                    /* EXECUTA */
                    xhr.send(params);

                 })( jQuery, window, document );

           </script>
        '; 

    endif;
    

   if($exibircompradores=="" && $modelojuntas=="sim" && $modelo4 ==""):

        $cor_background = get_field("cor_reserva_juntas",$rifa);
        $cor_texto      = get_field("cor_texto_juntas",$rifa);

        $cor_background_rifapresencial = get_field("cor_reserva_juntas_rifa_presencial",$rifa);
        $cor_texto_rifapresencial      = get_field("cor_texto_juntas_rifa_presencial",$rifa);
        
        $cor_comprada_juntas = get_field("cor_comprada_juntas",$rifa);
        $cor_texto_compradas_juntas = get_field("cor_texto_compradas_juntas",$rifa);
        
        $exibir_nome_do_comprador_ou_texto_padrao = get_field("exibir_nome_do_comprador_ou_texto_padrao",$rifa);

        $texto_tooltip_reserva_presencial = get_field("texto_tooltip_reserva_presencial",$rifa);

        $texto_tooltip_reserva = get_field("texto_tooltip_reserva",$rifa);
        $texto_tooltip_comprado = get_field("texto_tooltip_comprado",$rifa);

         $estilo_cota = "";

        if(get_field("tipo_de_cota",$rifa)=="Cota redonda"):

            $estilo_cota = '

                .form-check-label {
                    margin-bottom: 0;
                    border-radius: 100% !important;
                    height: 53px !important;
                }
                .cotas-disponiveis .form-check {
                    border-radius: 100% !important;
                }


            ';

        endif;

        return '

           <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />

           <style>

                .cotas-disponiveis .form-check{
                  border: 1px solid ' . get_field("cor_do_borda_cota_antes_selecao", $rifa) . ' !important;
                }

                .cotas-disponiveis .form-check input:checked + label{
                  background: ' . get_field("cor_de_fundo_selecao", $rifa) . ' !important;
                }
                
                #modalRifa .coluna-1 span{
                  background: ' . get_field("cor_de_fundo_selecao_modal_rodape", $rifa) . ' !important;
                }

                #modalRifa .coluna-2 h3 a{
                  color: ' . get_field("cor_do_texto_btn_finalizar_compra") . '  !important;
                  background: ' . get_field("cor_de_fundo_btn_finalizar_compra", $rifa) . ' !important;
              }

                .pcss3t > input:checked + label{
                    border-bottom: 2px solid ' . get_field("cor_do_borda_abas_livres_reservadas",$rifa) . ' !important;
              }

              '.$estilo_cota.'

             </style>




           <div class="cotas-disponiveis" id="cotasrifa_v2">
               <div id="pFprogresso" style="position:absolute;display:block;width:100%;height:100%;background:rgba(255,255,255,0.85);padding-top:30px;text-align:center;z-index:999;color:#000 !important;"><d>Carregando números</d> <span></span>
                 <div class="barra-progresso-carregamento" style="position:relative;display:block;width:200px;height:11px;background:#f2f2f2;margin-left: auto;margin-right: auto;margin-top: 12px;border-radius: 14px;">
                  <div class="thumb-barra" style="height:100%;position:relative;display:block;background:#62C75D;width:0;border-radius: 14px;"></div>
                 </div>
           </div>
           </div>
           <script type="text/javascript">

                 //console.log("Carregando rifa....");

                 ;(function ( $, window, document, undefined ) {

                      var ajaxurl = "'.get_site_url().'/wp-admin/admin-ajax.php";
  
                      let xhr = new XMLHttpRequest();
                       
                      xhr.open("POST", ajaxurl,true);
                      xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

                      var params = "action=exibir_cotas_ajax_v2&id='.$rifa.'";
                      
                      // INICIO AJAX VANILLA
                      xhr.onreadystatechange = () => {

                        if(xhr.readyState == 4) {

                              if(xhr.status == 200) {

                                  //console.log(JSON.parse(xhr.responseText));

                                  let dados = JSON.parse(xhr.responseText);

                                  // IMPRIMIR OS NÚMEROS
                                  var htmlCotasInicio = "";
                                  let pFprogresso = 0;
                                  var htmlDenovo = "";
                                  

                                  for(let i = 0;i<dados.cotas;i++){

                                      
                                       setTimeout(function() { 

                                            pFprogresso = i / dados.cotas * 100;

                                            jQuery("#pFprogresso span").html(`${pFprogresso.toFixed(2)}%`);
                                            jQuery(".thumb-barra").css("width",`${pFprogresso.toFixed(2)}%`);

                                            if(pFprogresso>50){
                                               jQuery("#pFprogresso d").html(`Consultando reservas`);
                                            }
                                            if(pFprogresso>70){
                                               jQuery("#pFprogresso d").html(`Consultando pagamentos`);
                                            }

                                            if(pFprogresso>90){
                                               jQuery("#pFprogresso d").html(`Quase terminando... `);
                                            }

                                            /*
                                            document.getElementById("cotasrifa_v2").insertAdjacentHTML("beforeend",`

                                                <div class="form-check" id="fc${coloque_zero(i,dados.globos)}">
                                                  <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                  <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                    ${coloque_zero(i,dados.globos)}
                                                  </label>
                                                </div>

                                            `);

                                            if(i==dados.cotas-1){ conferirNumeros(); }
                                            */

                                        }, 0);
                                        
                                        

                                        htmlDenovo = htmlDenovo + `

                                               <div class="form-check" id="fc${coloque_zero(i,dados.globos)}">
                                                  <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                  <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                    ${coloque_zero(i,dados.globos)}
                                                  </label>
                                                </div>

                                        `;

                                        

                                          
                                  }

                                  
                                  setTimeout(function() { 

                                    document.getElementById("cotasrifa_v2").innerHTML = `${htmlDenovo}`;

                                    conferirNumeros();
                                    
                                  }, 2500);
                                  

                                  
                                  function conferirNumeros(){

                                      var numeros_escolhidos = "";
                                      jQuery("#pFprogresso").remove();

                                        // ELIMINAR AS COTAS JÁ RESERVADAS
                                        for(let i = 0;i<dados.participantes.length;i++){

                                            numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                            var numero_isolado;
                                            var a = 0;
                                            while(a<numeros_escolhidos.length){

                                              numero_isolado = numeros_escolhidos[a];


                                              // ALTERANDO O ESTILO DA COTA JÁ RESERVADA
                                              jQuery(`#fc${numero_isolado} input`).attr("disabled","true");


                                              // TOOLTIP AO PASSAR O MOUSE POR CIMA DA COTA
                                              jQuery(`#fc${numero_isolado}`).addClass("me-de-tooltip");

                                              jQuery(`#fc${numero_isolado}`).attr("status-numero",dados.participantes[i].status);

                                              jQuery(`#fc${numero_isolado} label`).addClass("label-desativado");


                                              // AGUARDANDO PAGAMENTO
                                              if(dados.participantes[i].status=="on-hold" ||dados.participantes[i].status== "pending"){
                                                  
                                                  jQuery(`#fc${numero_isolado}`).attr("aria-label","'.$texto_tooltip_reserva.'");

                                                  jQuery(`#fc${numero_isolado} .label-desativado`).css("background","'.$cor_background.'");
                                                  
                                                  jQuery(`#fc${numero_isolado} .label-desativado`).css("color","'.$cor_texto.'");

                                              }


                                              // RIFA PRESENCIAL
                                              if(dados.participantes[i].status== "rifa-presencial"){
                                                  
                                                  jQuery(`#fc${numero_isolado}`).attr("aria-label","'.$texto_tooltip_reserva_presencial.'");

                                                  jQuery(`#fc${numero_isolado} .label-desativado`).css("background","'.$cor_background_rifapresencial.'");
                                                  
                                                  jQuery(`#fc${numero_isolado} .label-desativado`).css("color","'.$cor_texto_rifapresencial.'");

                                              }



                                              // PROCESSANDO OU COMPLETADO
                                              if(dados.participantes[i].status=="processing" || dados.participantes[i].status=="completed"){

                                                var opcaoTextoTooltip = "'.$exibir_nome_do_comprador_ou_texto_padrao.'";

                                                 if(opcaoTextoTooltip!="Nome comprador"){

                                                      jQuery(`#fc${numero_isolado}`).attr("aria-label","'.$texto_tooltip_comprado.'");

                                                }else{

                                                      var nome = dados.participantes[i].primeiro_nome;
                                                      var sobrenome = dados.participantes[i].ultimo_nome;

                                                      jQuery(`#fc${numero_isolado}`).attr("aria-label",`

                                                        ${nome} ${sobrenome}

                                                      `);

                                                }
                                                  
                                                  
                                                  jQuery(`#fc${numero_isolado} .label-desativado`).css("background","'.$cor_comprada_juntas.'");
                                                  
                                                  jQuery(`#fc${numero_isolado} .label-desativado`).css("color","'.$cor_texto_compradas_juntas.'");

                                              }
                                                                                     

                                              //console.log("MUDANDO STATUS RIFA: "+"#fc"+numero_isolado);

                                              a++;
                                            
                                            }

                                        }

                                        if (typeof reservasTemporarias === "function") { 
                                              reservasTemporarias();
                                          }else{
                                              console.log("Nenhuma extensão instalada");
                                        }

                                        setTimeout(function(){ 

                                            preencherNumerosPreSelecionados(); 

                                          }, 1000);

                                  }
                                                                 
                              }
                                                       
                        }

                    }; // FINAL AJAX VANILLA

                    /* EXECUTA */
                    xhr.send(params);

                 })( jQuery, window, document );

           </script>
        '; 

   endif; 


   if($exibircompradores=="sim"):

           $total_d = 0; // DISPONIVEIS
           $total_r = 0; // RESERVADAS
           $total_c = 0; // COMPRAPAS  
           $total_p = 0; // PARTICIPANTES  

           $html_estilo = ""; 
           $subs_email  = "";

           if(get_field("exibir_email",$rifa)=="n"):

              $subs_email = "n.email = '******';";
              $html_estilo = "

                  <style>
                      .email_rifa{
                        display: none !important;
                      }
                  </style>

              ";
           endif;


            $estilo_cota = "";

        if(get_field("tipo_de_cota",$rifa)=="Cota redonda"):

            $estilo_cota = '

                .form-check-label {
                    margin-bottom: 0;
                    border-radius: 100% !important;
                    height: 53px !important;
                }
                .cotas-disponiveis .form-check {
                    border-radius: 100% !important;
                }


            ';

        endif;


        return '

                  <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />

                  <style>

                      .cotas-disponiveis .form-check{
                        border: 1px solid ' . get_field("cor_do_borda_cota_antes_selecao", $rifa) . ' !important;
                      }

                      .cotas-disponiveis .form-check input:checked + label{
                        background: ' . get_field("cor_de_fundo_selecao", $rifa) . ' !important;
                      }
                      
                      #modalRifa .coluna-1 span{
                        background: ' . get_field("cor_de_fundo_selecao_modal_rodape", $rifa) . ' !important;
                      }

                      #modalRifa .coluna-2 h3 a{
                        color: ' . get_field("cor_do_texto_btn_finalizar_compra") . '  !important;
                        background: ' . get_field("cor_de_fundo_btn_finalizar_compra", $rifa) . ' !important;
                    }

                      .pcss3t > input:checked + label{
                          border-bottom: 2px solid ' . get_field("cor_do_borda_abas_livres_reservadas",$rifa) . ' !important;
                    }

                    '.$estilo_cota.'

                   </style>

                  <div class="cotas-disponiveis" id="cotasDisponiveisSelector">

                         <div id="pFprogresso" style="position:absolute;display:block;width:100%;height:100%;background:rgba(255,255,255,0.85);padding-top:30px;text-align:center;z-index:999;color:#000 !important;"><d>Carregando números</d> <span></span>
                                           <div class="barra-progresso-carregamento" style="position:relative;display:block;width:200px;height:11px;background:#f2f2f2;margin-left: auto;margin-right: auto;margin-top: 12px;border-radius: 14px;">
                                            <div class="thumb-barra" style="height:100%;position:relative;display:block;background:#62C75D;width:0;border-radius: 14px;"></div>
                                           </div>
                          </div> 

                         <!-- ABAS -->
                         <div class="page-tabs">
                            <div class="pcss3t pcss3t-height-auto">
                                 
                                   <input type="radio" name="pcss3t" checked id="tab1" class="tab-content-first">
                                   <label for="tab1">LIVRES (<span id="totalL"></span>)</label>
                                                                                        
                                   <input type="radio" name="pcss3t"  id="tab2" class="tab-content-2">
                                   <label for="tab2">RESERVADAS (<span id="totalR"></span>)</label>

                                   <input type="radio" name="pcss3t"  id="tab3" class="tab-content-3">
                                   <label for="tab3">COMPRADAS (<span id="totalC"></span>)</label>

                                   <input type="radio" name="pcss3t"  id="tab4" class="tab-content-4">
                                   <label for="tab4">PARTICIPANTES (<span id="totalP"></span>)</label>

                                 <ul style="padding-left:0px;margin-left:0px;">
                                                                                             
                                   <!-- ABA UM -->
                                   <li class="tab-content tab-content-first" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba1">
                                   </li>
                                   <!-- ABA UM -->

                                   <!-- ABA DOIS -->
                                   <li class="tab-content tab-content-2" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba2">
                                      
                                   </li>
                                   <!-- ABA DOIS -->

                                   <!-- ABA TRES -->
                                   <li class="tab-content tab-content-3" style="padding-left:0px !important;padding-right:0px !important;"  id="iteneRifaAba3">
                                      
                                   </li>
                                   <!-- ABA TRES -->

                                   <!-- ABA QUATRO -->
                                   <li class="tab-content tab-content-4" style="padding-left:0px !important;padding-right:0px !important;"  id="iteneRifaAba4">
                                       
                                   </li>
                                   <!-- ABA QUATRO -->

                                 </ul>

                            </div>
                          </div>
                          <!-- ABAS -->
                    </div>


                    <script type="text/javascript">

                         console.log("Carregando rifa....");

                         var totalL = 0;
                         var totalR = 0;
                         var totalC = 0;
                         var totalP = 0;
                         var calcs = 0;

                         ;(function ( $, window, document, undefined ) {

                              var ajaxurl = "'.get_site_url().'/wp-admin/admin-ajax.php";
          
                              let xhr = new XMLHttpRequest();
                               
                              xhr.open("POST", ajaxurl,true);
                              xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

                              var params = "action=exibir_cotas_ajax_v2&id='.$rifa.'";
                              
                              // INICIO AJAX VANILLA
                              xhr.onreadystatechange = () => {

                                if(xhr.readyState == 4) {

                                      if(xhr.status == 200) {

                                          //console.log(JSON.parse(xhr.responseText));

                                          var dados = JSON.parse(xhr.responseText);


                                          // ######### ABA 1

                                          // IMPRIMIR OS NÚMEROS
                                          var htmlCotasInicio = "";
                                          let pFprogresso = 0;

                                          let html1 = "";
                                          let html2 = "";
                                          let html3 = "";
                                          let html4 = "";

                                          for(let i = 0;i<dados.cotas;i++){

                                            
                                               setTimeout(function() { 

                                                  pFprogresso = i / dados.cotas * 100;

                                                  jQuery("#pFprogresso span").html(`${pFprogresso.toFixed(2)}%`);
                                                  jQuery(".thumb-barra").css("width",`${pFprogresso.toFixed(2)}%`);

                                                  if(pFprogresso>50){
                                                     jQuery("#pFprogresso d").html(`Consultando reservas`);
                                                  }
                                                  if(pFprogresso>70){
                                                     jQuery("#pFprogresso d").html(`Consultando pagamentos`);
                                                  }

                                                  if(pFprogresso>90){
                                                     jQuery("#pFprogresso d").html(`Quase terminando... `);
                                                  }

                                                  /*
                                                  jQuery("#iteneRifaAba1").append(`

                                                      <div class="form-check conteme1" id="fc${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>

                                                  `);

                                                  jQuery("#iteneRifaAba2").append(`

                                                      <div class="form-check" style="display:none;" id="fcr${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotar${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotar${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>

                                                  `);

                                                  jQuery("#iteneRifaAba3").append(`

                                                      <div class="form-check" style="display:none;" id="fcc${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotac${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotac${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>

                                                  `);

                                                  if(i==dados.cotas-1){ conferirNumeros(); }

                                                  */

                                              }, 0);

                                            

                                              html1 = html1 + `
                                                <div class="form-check conteme1" id="fc${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>
                                              `;

                                              html2 = html2 + `
                                                <div class="form-check" style="display:none;" id="fcr${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotar${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotar${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>
                                              `;

                                              html3 = html3 + `
                                                <div class="form-check" style="display:none;" id="fcc${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotac${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotac${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>
                                              `;

                                              

                                          }

                                          
                                          setTimeout(function() { 

                                              document.getElementById("iteneRifaAba1").innerHTML =`${html1}`;
                                              document.getElementById("iteneRifaAba2").innerHTML =`${html2}`;
                                              document.getElementById("iteneRifaAba3").innerHTML =`${html3}`;

                                              conferirNumeros();
                                            
                                          }, 2500);

                                          

                                          function conferirNumeros(){

                                            jQuery("#pFprogresso").remove();

                                              // ELIMINAR AS COTAS JÁ RESERVADAS
                                              for(let i = 0;i<dados.participantes.length;i++){

                                                  var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                  var numero_isolado;
                                                  var a = 0;
                                                  while(a<numeros_escolhidos.length){

                                                    numero_isolado = numeros_escolhidos[a];

                                                    calcs++;

                                                    // REMOVER O NÚMERO JÁ RESERVADO
                                                    jQuery(`#fc${numero_isolado}`).hide(0);
                                                    jQuery(`#fc${numero_isolado}`).removeClass("conteme1");

                                                    //console.log("TENTANDO REMOVER: "+"#fc"+numero_isolado);

                                                    a++;
                                                  
                                                  }

                                              }// FINAL DO FOR

                                              totalL = jQuery(".conteme1").length;

                                              


                                              // ######### ABA 2
                                          calcs = 0;

                                          // IMPRIMIR OS NÚMEROS
                                          

                                          // EXIBIR AS COTAS JÁ RESERVADAS
                                          for(let i = 0;i<dados.participantes.length;i++){

                                              if(dados.participantes[i].status=="on-hold" ||
                                                 dados.participantes[i].status== "pending" ||
                                                 dados.participantes[i].status== "rifa-presencial"){

                                                var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                var numero_isolado;
                                                var a = 0;
                                                while(a<numeros_escolhidos.length){

                                                  numero_isolado = numeros_escolhidos[a];

                                                  calcs++;

                                                  // EXIBIR O NÚMERO JÁ RESERVADO
                                                  jQuery(`#fcr${numero_isolado}`).show(0);
                                                  jQuery(`#fcr${numero_isolado}`).addClass("conteme2");

                                                  //console.log("TENTANDO EXIBIR: "+"#fcr"+numero_isolado);

                                                  a++;
                                                
                                                }

                                             }// IF DO STATUS



                                          }// FINAL DO FOR

                                          totalR = jQuery(".conteme2").length;


                                          // ######### ABA 3
                                          calcs = 0;

                                          // IMPRIMIR OS NÚMEROS
                                          htmlCotasInicio = "";
                                          

                                          // EXIBIR AS COTAS JÁ COMPRADAS
                                          for(let i = 0;i<dados.participantes.length;i++){

                                              if(dados.participantes[i].status=="processing" || dados.participantes[i].status=="completed"){

                                                var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                var numero_isolado;
                                                var a = 0;
                                                while(a<numeros_escolhidos.length){

                                                  numero_isolado = numeros_escolhidos[a];

                                                  calcs++;

                                                  // EXIBIR O NÚMERO JÁ COMPRADO
                                                  jQuery(`#fcc${numero_isolado}`).show(0);
                                                  jQuery(`#fcc${numero_isolado}`).addClass("conteme3");

                                                  //console.log("TENTANDO EXIBIR: "+"#fcc"+numero_isolado);

                                                  a++;
                                                
                                                }

                                             }// IF DO STATUS



                                          }// FINAL DO FOR

                                          totalC = jQuery(".conteme3").length;


                                          // ######### ABA 4
                                          calcs = 0;
                                          var style="";

                                          jQuery("#iteneRifaAba4").html(`

                                              <table class="table table-bordered">

                                                <thead>
                                                    <th>Nome</th>
                                                    <th class="email_rifa">E-mail</th>
                                                    <th>Cotas escolhidas</th>
                                                </thead>
                                               
                                               <tbody id="rifaListaParticipantes">

                                                    ${dados.participantes.map((n) => {

                                                      style = "";

                                                      '.$subs_email.'

                                                      if(n.status=="processing" || n.status=="completed"){

                                                        calcs++;

                                                      }else{

                                                          style=`style="display:none;"`;
                                                          
                                                      }  

                                                        // ALIMENTAR O HTML
                                                        return `
                                                            
                                                           <tr ${style}>
                                                              <td>${n.primeiro_nome} ${n.ultimo_nome}</td>
                                                              <td class="email_rifa">${n.email.replace("a","***")}</td>
                                                              <td>${n.cotas_escolhidas}</td>
                                                           </tr>

                                                          `
                                                
                                                          }).join("")}                                                         
                                               </tbody>
                                               </table>

                                               '.$html_estilo.'

                                          `);

                                          totalP = calcs;

                                          jQuery("#totalL").html(totalL);
                                          jQuery("#totalR").html(totalR);
                                          jQuery("#totalC").html(totalC);
                                          jQuery("#totalP").html(totalP);


                                          if (typeof reservasTemporarias === "function") { 
                                              reservasTemporarias();
                                          }else{
                                              console.log("Nenhuma extensão instalada");
                                          }

                                          setTimeout(function(){ 

                                            preencherNumerosPreSelecionados(); 

                                          }, 1000);

                                          

                                          }
                                       
                                      }
                                                               
                                }

                            }; // FINAL AJAX VANILLA

                            /* EXECUTA */
                            xhr.send(params);

                        })( jQuery, window, document );

           </script>


        ';
   

   endif; 


   // EXIBIR COMPRADOS NO MODELO ABAS
   if($exibircompradores=="sim"):

           

          $total_d = 0; // DISPONIVEIS
           $total_r = 0; // RESERVADAS
           $total_c = 0; // COMPRAPAS  
           $total_p = 0; // PARTICIPANTES  

           $html_estilo = ""; 
           $subs_email  = "";

           if(get_field("exibir_email",$rifa)=="n"):

              $subs_email = "n.email = '******';";
              $html_estilo = "

                  <style>
                      .email_rifa{
                        display: none !important;
                      }
                  </style>

              ";
           endif;


            $estilo_cota = "";

        if(get_field("tipo_de_cota",$rifa)=="Cota redonda"):

            $estilo_cota = '

                .form-check-label {
                    margin-bottom: 0;
                    border-radius: 100% !important;
                    height: 53px !important;
                }
                .cotas-disponiveis .form-check {
                    border-radius: 100% !important;
                }


            ';

        endif;


        return '

                  <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />

                  <style>

                      .cotas-disponiveis .form-check{
                        border: 1px solid ' . get_field("cor_do_borda_cota_antes_selecao", $rifa) . ' !important;
                      }

                      .cotas-disponiveis .form-check input:checked + label{
                        background: ' . get_field("cor_de_fundo_selecao", $rifa) . ' !important;
                      }
                      
                      #modalRifa .coluna-1 span{
                        background: ' . get_field("cor_de_fundo_selecao_modal_rodape", $rifa) . ' !important;
                      }

                      #modalRifa .coluna-2 h3 a{
                        color: ' . get_field("cor_do_texto_btn_finalizar_compra") . '  !important;
                        background: ' . get_field("cor_de_fundo_btn_finalizar_compra", $rifa) . ' !important;
                    }

                      .pcss3t > input:checked + label{
                          border-bottom: 2px solid ' . get_field("cor_do_borda_abas_livres_reservadas",$rifa) . ' !important;
                    }

                    '.$estilo_cota.'

                   </style>

                  <div class="cotas-disponiveis" id="cotasDisponiveisSelector">

                         <div id="pFprogresso" style="position:absolute;display:block;width:100%;height:100%;background:rgba(255,255,255,0.85);padding-top:30px;text-align:center;z-index:999;color:#000 !important;"><d>Carregando números</d> <span></span>
                                           <div class="barra-progresso-carregamento" style="position:relative;display:block;width:200px;height:11px;background:#f2f2f2;margin-left: auto;margin-right: auto;margin-top: 12px;border-radius: 14px;">
                                            <div class="thumb-barra" style="height:100%;position:relative;display:block;background:#62C75D;width:0;border-radius: 14px;"></div>
                                           </div>
                          </div> 

                         <!-- ABAS -->
                         <div class="page-tabs">
                            <div class="pcss3t pcss3t-height-auto">
                                 
                                   <input type="radio" name="pcss3t" checked id="tab1" class="tab-content-first">
                                   <label for="tab1">LIVRES (<span id="totalL"></span>)</label>
                                                                                        
                                   <input type="radio" name="pcss3t"  id="tab2" class="tab-content-2">
                                   <label for="tab2">RESERVADAS (<span id="totalR"></span>)</label>

                                   <input type="radio" name="pcss3t"  id="tab3" class="tab-content-3">
                                   <label for="tab3">COMPRADAS (<span id="totalC"></span>)</label>

                                   <input type="radio" name="pcss3t"  id="tab4" class="tab-content-4">
                                   <label for="tab4">PARTICIPANTES (<span id="totalP"></span>)</label>

                                 <ul style="padding-left:0px;margin-left:0px;">
                                                                                             
                                   <!-- ABA UM -->
                                   <li class="tab-content tab-content-first" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba1">
                                   </li>
                                   <!-- ABA UM -->

                                   <!-- ABA DOIS -->
                                   <li class="tab-content tab-content-2" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba2">
                                      
                                   </li>
                                   <!-- ABA DOIS -->

                                   <!-- ABA TRES -->
                                   <li class="tab-content tab-content-3" style="padding-left:0px !important;padding-right:0px !important;"  id="iteneRifaAba3">
                                      
                                   </li>
                                   <!-- ABA TRES -->

                                   <!-- ABA QUATRO -->
                                   <li class="tab-content tab-content-4" style="padding-left:0px !important;padding-right:0px !important;"  id="iteneRifaAba4">
                                       
                                   </li>
                                   <!-- ABA QUATRO -->

                                 </ul>

                            </div>
                          </div>
                          <!-- ABAS -->
                    </div>


                    <script type="text/javascript">

                         console.log("Carregando rifa....");

                         var totalL = 0;
                         var totalR = 0;
                         var totalC = 0;
                         var totalP = 0;
                         var calcs = 0;

                         ;(function ( $, window, document, undefined ) {

                              var ajaxurl = "'.get_site_url().'/wp-admin/admin-ajax.php";
          
                              let xhr = new XMLHttpRequest();
                               
                              xhr.open("POST", ajaxurl,true);
                              xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

                              var params = "action=exibir_cotas_ajax_v2&id='.$rifa.'";
                              
                              // INICIO AJAX VANILLA
                              xhr.onreadystatechange = () => {

                                if(xhr.readyState == 4) {

                                      if(xhr.status == 200) {

                                          //console.log(JSON.parse(xhr.responseText));

                                          var dados = JSON.parse(xhr.responseText);


                                          // ######### ABA 1

                                          // IMPRIMIR OS NÚMEROS
                                          var htmlCotasInicio = "";
                                          let pFprogresso = 0;

                                          let html1 = "";
                                          let html2 = "";
                                          let html3 = "";
                                          let html4 = "";

                                          for(let i = 0;i<dados.cotas;i++){

                                            
                                               setTimeout(function() { 

                                                  pFprogresso = i / dados.cotas * 100;

                                                  jQuery("#pFprogresso span").html(`${pFprogresso.toFixed(2)}%`);
                                                  jQuery(".thumb-barra").css("width",`${pFprogresso.toFixed(2)}%`);

                                                  if(pFprogresso>50){
                                                     jQuery("#pFprogresso d").html(`Consultando reservas`);
                                                  }
                                                  if(pFprogresso>70){
                                                     jQuery("#pFprogresso d").html(`Consultando pagamentos`);
                                                  }

                                                  if(pFprogresso>90){
                                                     jQuery("#pFprogresso d").html(`Quase terminando... `);
                                                  }

                                                  /*
                                                  jQuery("#iteneRifaAba1").append(`

                                                      <div class="form-check conteme1" id="fc${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>

                                                  `);

                                                  jQuery("#iteneRifaAba2").append(`

                                                      <div class="form-check" style="display:none;" id="fcr${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotar${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotar${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>

                                                  `);

                                                  jQuery("#iteneRifaAba3").append(`

                                                      <div class="form-check" style="display:none;" id="fcc${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotac${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotac${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>

                                                  `);

                                                  if(i==dados.cotas-1){ conferirNumeros(); }

                                                  */

                                              }, 0);

                                            

                                              html1 = html1 + `
                                                <div class="form-check conteme1" id="fc${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>
                                              `;

                                              html2 = html2 + `
                                                <div class="form-check" style="display:none;" id="fcr${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotar${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotar${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>
                                              `;

                                              html3 = html3 + `
                                                <div class="form-check" style="display:none;" id="fcc${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotac${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotac${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>
                                              `;

                                              

                                          }

                                          
                                          setTimeout(function() { 

                                              document.getElementById("iteneRifaAba1").innerHTML =`${html1}`;
                                              document.getElementById("iteneRifaAba2").innerHTML =`${html2}`;
                                              document.getElementById("iteneRifaAba3").innerHTML =`${html3}`;

                                              conferirNumeros();
                                            
                                          }, 2500);

                                          

                                          function conferirNumeros(){

                                            jQuery("#pFprogresso").remove();

                                              // ELIMINAR AS COTAS JÁ RESERVADAS
                                              for(let i = 0;i<dados.participantes.length;i++){

                                                  var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                  var numero_isolado;
                                                  var a = 0;
                                                  while(a<numeros_escolhidos.length){

                                                    numero_isolado = numeros_escolhidos[a];

                                                    calcs++;

                                                    // REMOVER O NÚMERO JÁ RESERVADO
                                                    jQuery(`#fc${numero_isolado}`).hide(0);
                                                    jQuery(`#fc${numero_isolado}`).removeClass("conteme1");

                                                    //console.log("TENTANDO REMOVER: "+"#fc"+numero_isolado);

                                                    a++;
                                                  
                                                  }

                                              }// FINAL DO FOR

                                              totalL = jQuery(".conteme1").length;

                                              


                                              // ######### ABA 2
                                          calcs = 0;

                                          // IMPRIMIR OS NÚMEROS
                                          

                                          // EXIBIR AS COTAS JÁ RESERVADAS
                                          for(let i = 0;i<dados.participantes.length;i++){

                                              if(dados.participantes[i].status=="on-hold" ||
                                                 dados.participantes[i].status== "pending" ||
                                                 dados.participantes[i].status== "rifa-presencial"){

                                                var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                var numero_isolado;
                                                var a = 0;
                                                while(a<numeros_escolhidos.length){

                                                  numero_isolado = numeros_escolhidos[a];

                                                  calcs++;

                                                  // EXIBIR O NÚMERO JÁ RESERVADO
                                                  jQuery(`#fcr${numero_isolado}`).show(0);
                                                  jQuery(`#fcr${numero_isolado}`).addClass("conteme2");

                                                  //console.log("TENTANDO EXIBIR: "+"#fcr"+numero_isolado);

                                                  a++;
                                                
                                                }

                                             }// IF DO STATUS



                                          }// FINAL DO FOR

                                          totalR = jQuery(".conteme2").length;


                                          // ######### ABA 3
                                          calcs = 0;

                                          // IMPRIMIR OS NÚMEROS
                                          htmlCotasInicio = "";
                                          

                                          // EXIBIR AS COTAS JÁ COMPRADAS
                                          for(let i = 0;i<dados.participantes.length;i++){

                                              if(dados.participantes[i].status=="processing" || dados.participantes[i].status=="completed"){

                                                var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                var numero_isolado;
                                                var a = 0;
                                                while(a<numeros_escolhidos.length){

                                                  numero_isolado = numeros_escolhidos[a];

                                                  calcs++;

                                                  // EXIBIR O NÚMERO JÁ COMPRADO
                                                  jQuery(`#fcc${numero_isolado}`).show(0);
                                                  jQuery(`#fcc${numero_isolado}`).addClass("conteme3");

                                                  //console.log("TENTANDO EXIBIR: "+"#fcc"+numero_isolado);

                                                  a++;
                                                
                                                }

                                             }// IF DO STATUS



                                          }// FINAL DO FOR

                                          totalC = jQuery(".conteme3").length;


                                          // ######### ABA 4
                                          calcs = 0;
                                          var style="";

                                          jQuery("#iteneRifaAba4").html(`

                                              <table class="table table-bordered">

                                                <thead>
                                                    <th>Nome</th>
                                                    <th class="email_rifa">E-mail</th>
                                                    <th>Cotas escolhidas</th>
                                                </thead>
                                               
                                               <tbody id="rifaListaParticipantes">

                                                    ${dados.participantes.map((n) => {

                                                      style = "";

                                                      '.$subs_email.'

                                                      if(n.status=="processing" || n.status=="completed"){

                                                        calcs++;

                                                      }else{

                                                          style=`style="display:none;"`;
                                                          
                                                      }  

                                                        // ALIMENTAR O HTML
                                                        return `
                                                            
                                                           <tr ${style}>
                                                              <td>${n.primeiro_nome} ${n.ultimo_nome}</td>
                                                              <td class="email_rifa">${n.email.replace("a","***")}</td>
                                                              <td>${n.cotas_escolhidas}</td>
                                                           </tr>

                                                          `
                                                
                                                          }).join("")}                                                         
                                               </tbody>
                                               </table>

                                               '.$html_estilo.'

                                          `);

                                          totalP = calcs;

                                          jQuery("#totalL").html(totalL);
                                          jQuery("#totalR").html(totalR);
                                          jQuery("#totalC").html(totalC);
                                          jQuery("#totalP").html(totalP);


                                          if (typeof reservasTemporarias === "function") { 
                                              reservasTemporarias();
                                          }else{
                                              console.log("Nenhuma extensão instalada");
                                          }

                                          setTimeout(function(){ 

                                            preencherNumerosPreSelecionados(); 

                                          }, 1000);

                                          

                                          }
                                       
                                      }
                                                               
                                }

                            }; // FINAL AJAX VANILLA

                            /* EXECUTA */
                            xhr.send(params);

                        })( jQuery, window, document );

           </script>


        ';
   

   endif; 


   // #### MODELO 4 ####
   if($exibircompradores=="" && $modelojuntas=="" && $modelo4 == "sim"):

           $total_total = 0; // TOTAL TOTAL
           $total_d = 0; // DISPONIVEIS
           $total_r = 0; // RESERVADAS
           $total_c = 0; // COMPRAPAS  
           $total_p = 0; // PARTICIPANTES  

           $quantidade_cotas = get_field("numero_de_cotas",$rifa);

           $html_estilo = ""; 
           $subs_email  = "";

           $cores_modelos_todas = get_field("cores_modelos_todas",$rifa);

           $cor_de_fundo_aba_todas = $cores_modelos_todas["cor_de_fundo_aba_todas"];
           $cor_do_texto_e_borda_aba_todas = $cores_modelos_todas["cor_do_texto_e_borda_aba_todas"];

           $cores_modelos_livres = get_field("cores_modelos_livres",$rifa);
           $cor_de_fundo_aba_livres = $cores_modelos_livres["cor_de_fundo_aba_livres"];
           $cor_do_texto_e_borda_aba_livres = $cores_modelos_livres["cor_do_texto_e_borda_aba_livres"];

           $cores_modelos_reservadas = get_field("cores_modelos_reservadas",$rifa);
           $cor_de_fundo_aba_reservadas = $cores_modelos_reservadas["cor_de_fundo_aba_reservadas"];
           $cor_do_texto_e_borda_aba_reservadas = $cores_modelos_reservadas["cor_do_texto_e_borda_aba_reservadas"];

           $cores_modelos_pagas = get_field("cores_modelos_pagas",$rifa);
           $cor_de_fundo_aba_pagas = $cores_modelos_pagas["cor_de_fundo_aba_pagas"];
           $cor_do_texto_e_borda_aba_pagas = $cores_modelos_pagas["cor_do_texto_e_borda_aba_pagas"];

           

           $estilo_modelo4 = ' 

              /**
              *  ------------------------------------------------------------------------------------------------
              *
              *
              *   MODELO 4
              *
              *
              *  ------------------------------------------------------------------------------------------------
              */
              .cotas-disponiveis-modelo-4 .pcss3t > label {
                  padding-left: 20px;
                  margin-right: 26px;
                  width: 175px;
                  background: #f2f2f2;
                  border-radius: 15px;
                  color: #000;
                  text-align: center;
                  opacity: 1;
                  border-bottom: unset;
              }

              .cotas-disponiveis-modelo-4 .pcss3t > input:checked + label {
                  /*border-bottom: 0px solid !important;*/
              }

              .cotas-disponiveis-modelo-4.cotas-disponiveis .form-check{
                  border: 1px solid !important;
                  border-radius: 100% !important;
                  height: 59px !important;
                  width: 59px !important;
                  padding-top: 2px;
              }

              @media(max-width: 540px){
                .cotas-disponiveis-modelo-4.cotas-disponiveis li.tab-content{
                  text-align: center;
                }
                .cotas-disponiveis-modelo-4.cotas-disponiveis .form-check{
                  display: inline-block;
                  float: none;
                }
                .cotas-disponiveis-modelo-4 .pcss3t > label{
                  width: 100%;
                }
              }
              .cotas-disponiveis-modelo-4.cotas-disponiveis .form-check label{
                 border-radius: 100% !important;
              }

              .cotas-disponiveis-modelo-4.cotas-disponiveis .form-check input:checked + label {
                  height: 59px !important;
                  width: 59px !important;
                  margin-top: -3px;
              }

              .label-aba-todas,
              .label-aba-todas:hover,
              .cotas-disponiveis-modelo-4 .pcss3t > input:checked + label.label-aba-todas{
                background: '.$cor_de_fundo_aba_todas.' !important;
                border:1px solid '.$cor_do_texto_e_borda_aba_todas.' !important;
                color: '.$cor_do_texto_e_borda_aba_todas.' !important;
              }

              .label-aba-participantes,
              .label-aba-participantes:hover{
                background: '.$cor_de_fundo_aba_todas.' !important;
                border:1px solid '.$cor_do_texto_e_borda_aba_todas.' !important;
                border-bottom:1px solid '.$cor_do_texto_e_borda_aba_todas.' !important;
                color: '.$cor_do_texto_e_borda_aba_todas.' !important;
              }

              .label-aba-livres,
              .label-aba-livres:hover,
              .cotas-disponiveis-modelo-4 .pcss3t > input:checked + label.label-aba-livres{
                background: '.$cor_de_fundo_aba_livres.' !important;
                border:1px solid '.$cor_do_texto_e_borda_aba_livres.' !important;
                color: '.$cor_do_texto_e_borda_aba_livres.' !important;
              }

              .label-aba-reservadas,
              .label-aba-reservadas:hover,
              .cotas-disponiveis-modelo-4 .pcss3t > input:checked + label.label-aba-reservadas{
                background: '.$cor_de_fundo_aba_reservadas.' !important;
                border:1px solid '.$cor_do_texto_e_borda_aba_reservadas.' !important;
                color: '.$cor_do_texto_e_borda_aba_reservadas.' !important;
              }
              .modelo-4-reservada{
                background: '.$cor_de_fundo_aba_reservadas.';
                border: 1px solid '.$cor_do_texto_e_borda_aba_reservadas.' !important;
                color:'.$cor_do_texto_e_borda_aba_reservadas.';
              }
              .modelo-4-reservada label{
                background: '.$cor_de_fundo_aba_reservadas.' !important; 
                color:'.$cor_do_texto_e_borda_aba_reservadas.' !important;
              }

              .label-aba-pagas,
              .label-aba-pagas:hover,
              .cotas-disponiveis-modelo-4 .pcss3t > input:checked + label.label-aba-pagas{
                background: '.$cor_de_fundo_aba_pagas.' !important;
                border:1px solid '.$cor_do_texto_e_borda_aba_pagas.' !important;
                color: '.$cor_do_texto_e_borda_aba_pagas.' !important;
              }
              .modelo-4-comprada{
                background: '.$cor_de_fundo_aba_pagas.';
                border: 1px solid '.$cor_do_texto_e_borda_aba_pagas.' !important;
                color: '.$cor_do_texto_e_borda_aba_pagas.';
              }
              .modelo-4-comprada label{
                background: '.$cor_de_fundo_aba_pagas.' !important; 
                color: '.$cor_do_texto_e_borda_aba_pagas.' !important;
              }

           ';


           if(get_field("exibir_email",$rifa)=="n"):

              $subs_email = "n.email = '******';";
              $html_estilo = "

                  <style>
                      .email_rifa{
                        display: none !important;
                      }
                  </style>

              ";
           endif;


            $estilo_cota = "";

        if(get_field("tipo_de_cota",$rifa)=="Cota redonda"):

            $estilo_cota = '

                .form-check-label {
                    margin-bottom: 0;
                    border-radius: 100% !important;
                    height: 53px !important;
                }
                .cotas-disponiveis .form-check {
                    border-radius: 100% !important;
                }


            ';

        endif;


        return '

                  <input type="hidden" id="idDoProdutoInput" value="'.$rifa.'" />

                  <style>

                      .cotas-disponiveis .form-check{
                        border: 1px solid ' . get_field("cor_do_borda_cota_antes_selecao", $rifa) . ' !important;
                      }

                      .cotas-disponiveis .form-check input:checked + label{
                        background: ' . get_field("cor_de_fundo_selecao", $rifa) . ' !important;
                        border: 1px solid ' . get_field("cor_de_fundo_selecao", $rifa) . ';
                      }
                      
                      #modalRifa .coluna-1 span{
                        background: ' . get_field("cor_de_fundo_selecao_modal_rodape", $rifa) . ' !important;
                      }

                      #modalRifa .coluna-2 h3 a{
                        color: ' . get_field("cor_do_texto_btn_finalizar_compra") . '  !important;
                        background: ' . get_field("cor_de_fundo_btn_finalizar_compra", $rifa) . ' !important;
                    }

                      /*.pcss3t > input:checked + label{
                          border-bottom: 2px solid ' . get_field("cor_do_borda_abas_livres_reservadas",$rifa) . ' !important;
                    }*/

                    '.$estilo_cota.'

                    '.$estilo_modelo4.'

                   </style>

                  <div class="cotas-disponiveis cotas-disponiveis-modelo-4" id="cotasDisponiveisSelector">

                         <div id="pFprogresso" style="position:absolute;display:block;width:100%;height:100%;background:rgba(255,255,255,0.85);padding-top:30px;text-align:center;z-index:999;color:#000 !important;"><d>Carregando números</d> <span></span>
                                           <div class="barra-progresso-carregamento" style="position:relative;display:block;width:200px;height:11px;background:#f2f2f2;margin-left: auto;margin-right: auto;margin-top: 12px;border-radius: 14px;">
                                            <div class="thumb-barra" style="height:100%;position:relative;display:block;background:#62C75D;width:0;border-radius: 14px;"></div>
                                           </div>
                          </div> 

                         <!-- ABAS -->
                         <div class="page-tabs">
                            <div class="pcss3t pcss3t-height-auto">
                                 
                                   <input type="radio" name="pcss3t" checked id="tabTodos" class="tab-content-first">
                                   <label class="label-aba-todas" for="tabTodos">TODAS (<span id="totalTodos">0</span>)</label>

                                   <input type="radio" name="pcss3t" id="tab1" class="tab-content-1">
                                   <label class="label-aba-livres" for="tab1">LIVRES (<span id="totalL">0</span>)</label>
                                                                                        
                                   <input type="radio" name="pcss3t" id="tab2" class="tab-content-2">
                                   <label class="label-aba-reservadas" for="tab2">RESERVADAS (<span id="totalR">0</span>)</label>

                                   <input type="radio" name="pcss3t" id="tab3" class="tab-content-3">
                                   <label class="label-aba-pagas" for="tab3">PAGAS (<span id="totalC">0</span>)</label>

                                   <input type="radio" name="pcss3t" id="tab4" class="tab-content-4">
                                   <label class="label-aba-participantes" for="tab4">PARTICIPANTES (<span id="totalP">0</span>)</label>

                                 <ul style="padding-left:0px;margin-left:0px;">
                                                                                             
                                   <!-- ABA ZERO -->
                                   <li class="tab-content aba-modelo4 aba-modelo4-0 tab-content-first" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba0">
                                   </li>
                                   <!-- ABA ZERO -->

                                   <!-- ABA UM -->
                                   <li class="tab-content aba-modelo4 aba-modelo4-1 tab-content-1" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba1">
                                   </li>
                                   <!-- ABA UM -->

                                   <!-- ABA DOIS -->
                                   <li class="tab-content aba-modelo4 aba-modelo4-2 tab-content-2" style="padding-left:0px !important;padding-right:0px !important;" id="iteneRifaAba2">
                                   </li>
                                   <!-- ABA DOIS -->

                                   <!-- ABA TRES -->
                                   <li class="tab-content aba-modelo4 aba-modelo4-3 tab-content-3" style="padding-left:0px !important;padding-right:0px !important;"  id="iteneRifaAba3">
                                   </li>
                                   <!-- ABA TRES -->

                                   <!-- ABA QUATRO -->
                                   <li class="tab-content aba-modelo4 aba-modelo4-4 tab-content-4" style="padding-left:0px !important;padding-right:0px !important;"  id="iteneRifaAba4">
                                   </li>
                                   <!-- ABA QUATRO -->

                                 </ul>

                            </div>
                          </div>
                          <!-- ABAS -->
                    </div>


                    <script type="text/javascript">

                         console.log("Carregando rifa....");

                         var totalTotals = 0;
                         var totalL = 0;
                         var totalR = 0;
                         var totalC = 0;
                         var totalP = 0;
                         var calcs = 0;

                         ;(function ( $, window, document, undefined ) {

                              var ajaxurl = "'.get_site_url().'/wp-admin/admin-ajax.php";
          
                              let xhr = new XMLHttpRequest();
                               
                              xhr.open("POST", ajaxurl,true);
                              xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

                              var params = "action=exibir_cotas_ajax_v2&id='.$rifa.'";
                              
                              // INICIO AJAX VANILLA
                              xhr.onreadystatechange = () => {

                                if(xhr.readyState == 4) {

                                      if(xhr.status == 200) {

                                          //console.log(JSON.parse(xhr.responseText));

                                          var dados = JSON.parse(xhr.responseText);


                                          // ######### ABA 1

                                          // IMPRIMIR OS NÚMEROS
                                          var htmlCotasInicio = "";
                                          let pFprogresso = 0;

                                          let htmlTodos = ""
                                          let html1 = "";
                                          let html2 = "";
                                          let html3 = "";
                                          let html4 = "";

                                          for(let i = 0;i<dados.cotas;i++){

                                            
                                               setTimeout(function() { 

                                                  pFprogresso = i / dados.cotas * 100;

                                                  jQuery("#pFprogresso span").html(`${pFprogresso.toFixed(2)}%`);
                                                  jQuery(".thumb-barra").css("width",`${pFprogresso.toFixed(2)}%`);

                                                  if(pFprogresso>50){
                                                     jQuery("#pFprogresso d").html(`Consultando reservas`);
                                                  }
                                                  if(pFprogresso>70){
                                                     jQuery("#pFprogresso d").html(`Consultando pagamentos`);
                                                  }

                                                  if(pFprogresso>90){
                                                     jQuery("#pFprogresso d").html(`Quase terminando... `);
                                                  }

                                                  /*
                                                  jQuery("#iteneRifaAba1").append(`

                                                      <div class="form-check conteme1" id="fc${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>

                                                  `);

                                                  jQuery("#iteneRifaAba2").append(`

                                                      <div class="form-check" style="display:none;" id="fcr${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotar${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotar${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>

                                                  `);

                                                  jQuery("#iteneRifaAba3").append(`

                                                      <div class="form-check" style="display:none;" id="fcc${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotac${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label label-um" for="cotac${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>

                                                  `);

                                                  if(i==dados.cotas-1){ conferirNumeros(); }

                                                  */

                                              }, 0);

                                            

                                              htmlTodos = htmlTodos + `
                                                <div class="form-check conteme1" id="fcTodos${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotas" onchange="selecionarCotaRifa(this.value)" value="${coloque_zero(i,dados.globos)}" id="cota${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cota${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>
                                              `;


                                              html1 = html1 + `
                                                <div class="form-check conteme1" id="fcClone${coloque_zero(i,dados.globos)}">
                                                    <input class="form-check-input" type="checkbox" name="cotasClone" onchange="selecionarCotaRifaClone(this.value)" value="${coloque_zero(i,dados.globos)}" id="cotaClone${coloque_zero(i,dados.globos)}">
                                                    <label class="form-check-label label-um" for="cotaClone${coloque_zero(i,dados.globos)}">
                                                      ${coloque_zero(i,dados.globos)}
                                                    </label>
                                                  </div>
                                              `;

                                              html2 = html2 + `
                                                <div class="form-check modelo-4-reservada" style="display:none;" id="fcr${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotar${coloque_zero(i,dados.globos)}">
                                                        <label class="form-check-label  label-um" for="cotar${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>
                                              `;

                                              html3 = html3 + `
                                                <div class="form-check modelo-4-comprada" style="display:none;" id="fcc${coloque_zero(i,dados.globos)}">
                                                        <input disabled class="form-check-input" type="checkbox" name="cotas" value="${coloque_zero(i,dados.globos)}" id="cotac${coloque_zero(i,dados.globos)}">
                                                        <label class=" form-check-label label-um" for="cotac${coloque_zero(i,dados.globos)}">
                                                          ${coloque_zero(i,dados.globos)}
                                                        </label>
                                                      </div>
                                              `;

                                              

                                          }

                                          
                                          setTimeout(function() { 

                                              document.getElementById("iteneRifaAba0").innerHTML =`${htmlTodos}`;
                                              document.getElementById("iteneRifaAba1").innerHTML =`${html1}`;
                                              document.getElementById("iteneRifaAba2").innerHTML =`${html2}`;
                                              document.getElementById("iteneRifaAba3").innerHTML =`${html3}`;

                                              conferirNumeros();
                                            
                                          }, 2500);

                                          

                                          function conferirNumeros(){

                                            jQuery("#pFprogresso").remove();

                                              // ELIMINAR AS COTAS JÁ RESERVADAS
                                              for(let i = 0;i<dados.participantes.length;i++){

                                                  var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                  var numero_isolado;
                                                  var a = 0;
                                                  while(a<numeros_escolhidos.length){

                                                    numero_isolado = numeros_escolhidos[a];

                                                    calcs++;

                                                    // REMOVER O NÚMERO JÁ RESERVADO
                                                    jQuery(`#fc${numero_isolado}`).hide(0);
                                                    jQuery(`#fc${numero_isolado}`).removeClass("conteme1");

                                                    jQuery(`#fcClone${numero_isolado}`).hide(0);
                                                    jQuery(`#fcClone${numero_isolado}`).removeClass("conteme1");

                                                    //console.log("TENTANDO REMOVER: "+"#fc"+numero_isolado);

                                                    a++;
                                                  
                                                  }

                                              }// FINAL DO FOR

                                              totalL = jQuery(".conteme1").length;

                                              


                                              // ######### ABA 2
                                          calcs = 0;

                                          // IMPRIMIR OS NÚMEROS
                                          

                                          // EXIBIR AS COTAS JÁ RESERVADAS
                                          for(let i = 0;i<dados.participantes.length;i++){

                                              if(dados.participantes[i].status=="on-hold" ||
                                                 dados.participantes[i].status== "pending" ||
                                                 dados.participantes[i].status== "rifa-presencial"){

                                                var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                var numero_isolado;
                                                var a = 0;
                                                while(a<numeros_escolhidos.length){

                                                  numero_isolado = numeros_escolhidos[a];

                                                  calcs++;

                                                  // EXIBIR O NÚMERO JÁ RESERVADO
                                                  jQuery(`#fcr${numero_isolado}`).show(0);
                                                  jQuery(`#fcr${numero_isolado}`).addClass("conteme2");

                                                  jQuery(`#fcTodos${numero_isolado}`).addClass("modelo-4-reservada");
                                                  jQuery(`#fcTodos${numero_isolado} input`).attr("disabled",true);


                                                  //console.log("TENTANDO EXIBIR: "+"#fcr"+numero_isolado);

                                                  a++;
                                                
                                                }

                                             }// IF DO STATUS



                                          }// FINAL DO FOR

                                          totalR = jQuery(".conteme2").length;


                                          // ######### ABA 3
                                          calcs = 0;

                                          // IMPRIMIR OS NÚMEROS
                                          htmlCotasInicio = "";
                                          

                                          // EXIBIR AS COTAS JÁ COMPRADAS
                                          for(let i = 0;i<dados.participantes.length;i++){

                                              if(dados.participantes[i].status=="processing" || dados.participantes[i].status=="completed"){

                                                var numeros_escolhidos = dados.participantes[i].cotas_escolhidas.split(",");

                                                var numero_isolado;
                                                var a = 0;
                                                while(a<numeros_escolhidos.length){

                                                  numero_isolado = numeros_escolhidos[a];

                                                  calcs++;

                                                  // EXIBIR O NÚMERO JÁ COMPRADO
                                                  jQuery(`#fcc${numero_isolado}`).show(0);
                                                  jQuery(`#fcc${numero_isolado}`).addClass("conteme3");

                                                  jQuery(`#fcTodos${numero_isolado}`).addClass("modelo-4-comprada");
                                                  jQuery(`#fcTodos${numero_isolado} input`).attr("disabled",true);

                                                  //console.log("TENTANDO EXIBIR: "+"#fcc"+numero_isolado);

                                                  a++;
                                                
                                                }

                                             }// IF DO STATUS



                                          }// FINAL DO FOR

                                          totalC = jQuery(".conteme3").length;


                                          // ######### ABA 4
                                          calcs = 0;
                                          var style="";

                                          jQuery("#iteneRifaAba4").html(`

                                              <table class="table table-bordered">

                                                <thead>
                                                    <th>Nome</th>
                                                    <th class="email_rifa">E-mail</th>
                                                    <th>Cotas escolhidas</th>
                                                </thead>
                                               
                                               <tbody id="rifaListaParticipantes">

                                                    ${dados.participantes.map((n) => {

                                                      style = "";

                                                      '.$subs_email.'

                                                      if(n.status=="processing" || n.status=="completed"){

                                                        calcs++;

                                                      }else{

                                                          style=`style="display:none;"`;
                                                          
                                                      }  

                                                        // ALIMENTAR O HTML
                                                        return `
                                                            
                                                           <tr ${style}>
                                                              <td>${n.primeiro_nome} ${n.ultimo_nome}</td>
                                                              <td class="email_rifa">${n.email.replace("a","***")}</td>
                                                              <td>${n.cotas_escolhidas}</td>
                                                           </tr>

                                                          `
                                                
                                                          }).join("")}                                                         
                                               </tbody>
                                               </table>

                                               '.$html_estilo.'

                                          `);

                                          totalP = calcs;

                                          var totalP2 = '.$quantidade_cotas.';

                                          totalL = totalP2 - totalR;
                                          totalL = totalL - totalC;

                                          jQuery("#totalL").html(totalL);
                                          jQuery("#totalR").html(totalR);
                                          jQuery("#totalC").html(totalC);
                                          jQuery("#totalP").html(totalP);

                                          totalTodos = totalL + totalR;
                                          totalTodos = totalTodos + totalC;
                                          

                                          $("#totalTodos").html('.$quantidade_cotas.');


                                          if (typeof reservasTemporarias === "function") { 
                                              reservasTemporarias();
                                          }else{
                                              console.log("Nenhuma extensão instalada");
                                          }

                                          setTimeout(function(){ 

                                            preencherNumerosPreSelecionados(); 

                                          }, 1000);

                                          

                                          }
                                       
                                      }
                                                               
                                }

                            }; // FINAL AJAX VANILLA

                            /* EXECUTA */
                            xhr.send(params);

                        })( jQuery, window, document );

           </script>


        ';

   endif; 

    
}

add_shortcode('exibir_cotas_v2', 'funcao_cotasrifa_v2');

function get_orders_ids_by_product_id( $product_id, $order_status = array( 'wc-completed', 'wc-processing', 'wc-on-hold', 'wc-pending', 'wc-rifa-presencial' ) ){

    global $wpdb;

    $results = $wpdb->get_col("
        SELECT order_items.order_id
        FROM {$wpdb->prefix}woocommerce_order_items as order_items
        LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta as order_item_meta ON order_items.order_item_id = order_item_meta.order_item_id
        LEFT JOIN {$wpdb->posts} AS posts ON order_items.order_id = posts.ID
        WHERE posts.post_type = 'shop_order'
        AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
        AND order_items.order_item_type = 'line_item'
        AND order_item_meta.meta_key = '_product_id'
        AND order_item_meta.meta_value = '$product_id'
    ");

    return $results;
}

function ajaxExibir_cotas_v2() {

      $rifa = $_POST["id"];

      $args = array( 'post_type' => 'product', 
                         'p' => $rifa, 

      );

        $loop = new WP_Query( $args );
        while ( $loop->have_posts() ) : $loop->the_post(); 
        
            $cotas = get_field("numero_de_cotas");
            $globos = get_field("numero_globos");

            $reservas = get_user_meta( get_the_ID(), "diogenesjunior.ti@gmail.com");

            $participantes = get_users(array('meta_key' => get_the_ID() ));
        
        endwhile; 
        wp_reset_query(); 


      $pedidos = get_orders_ids_by_product_id($rifa);

      $a = 0;
      $b = 0;
      $array_cotas = array();


      while($a<count($pedidos)):

        $order = wc_get_order( $pedidos[$a] );

        $array_cotas[$b]["status"] = $order->get_status();

         $array_cotas[$b]["cotas_escolhidas"] = get_post_meta( $order->get_order_number(), 'billing_cotasescolhidas', true );

         $array_cotas[$b]["primeiro_nome"] = $order->get_billing_first_name();
         $array_cotas[$b]["ultimo_nome"] = $order->get_billing_last_name();
         $array_cotas[$b]["email"] = $order->get_billing_email();
         $array_cotas[$b]["phone"] = $order->get_billing_phone();

         $b++;
 
        $a++;
      endwhile;

      $data = array('sucesso' => "200", 'rifa' => $rifa, 'cotas' => $cotas, 'reservas' => $reservas, 'participantes' => $array_cotas, 'globos' => $globos);

      $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
      echo $json_string; 

      wp_die();

}

add_action('wp_ajax_exibir_cotas_ajax_v2', 'ajaxExibir_cotas_v2');
add_action( 'wp_ajax_nopriv_exibir_cotas_ajax_v2', 'ajaxExibir_cotas_v2' );



function pluginrifa_produtos(){

          $args = array( 'post_type' => 'product', 
                         'showposts' => '-1', 
                         'posts_per_page' => '-1'
                        );

          $produtos = array();

          $loop = new WP_Query( $args );
          
          $a = 0;

          while ( $loop->have_posts() ) : $loop->the_post(); 
                                      
            $produtos[$a]["id"] = get_the_ID();
            $produtos[$a]["titulo"] = get_the_title();
            $a++;

          endwhile; 
          wp_reset_query(); 

          // RETORNAR OS DADOS
          $data = array('sucesso' => "200", 'produtos' => $produtos);

          $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
          echo $json_string; 
          
          wp_die();

}

add_action('wp_ajax_pluginrifa_produtos', 'pluginrifa_produtos');
add_action('wp_ajax_nopriv_pluginrifa_produtos', 'pluginrifa_produtos' );

// CRIAR O NOVO PEDIDO
function pluginrifa_enviarpedido(){

          // RECUPERAR OS PEDIDOS
          $nome = $_POST["nome"];

          $temp = explode(" ",$nome);
          $primeiro_nome = $temp[0];

          $a = 1;
          while($a<count($temp)):

            $sobrenome = $sobrenome . $temp[$a] . " ";

            $a++;

          endwhile;

          global $woocommerce;

          $email = $_POST["email"];
          $produto = $_POST["produto"];
          $cotas = $_POST["cotas"];
          $quantidade = $_POST["quantidade"];
          $nota = $_POST["nota"];

          $address = array(
              'first_name' => $primeiro_nome,
              'last_name'  => $sobrenome,
              'email'      => $email
          );

          $order_data                        = array();
          $order_data[ 'post_type' ]         = 'shop_order';
          $order_data[ 'post_status' ]       = 'wc-' . apply_filters( 'woocommerce_default_order_status', 'processing' );
          $order_data[ 'ping_status' ]       = 'closed';
          $order_data[ 'post_author' ]       = 1;
          $order_data[ 'post_password' ]     = uniqid( 'order_' );
          $order_data[ 'post_title' ]        = sprintf( __( 'Order &ndash; %s', 'woocommerce' ), strftime( _x( '%b %d, %Y @ %I:%M %p', 'Order date parsed by strftime', 'woocommerce' ), strtotime( $post_date ) ) );
          //$order_data[ 'post_parent' ]       = 12; // parent post id
          $order_data[ 'post_content' ]      = "";
          $order_data[ 'comment_status' ]    = "open";
          $order_data[ 'post_name' ]         = sanitize_title( sprintf( __( 'Order &ndash; %s', 'woocommerce' ), strftime( _x( '%b %d, %Y @ %I:%M %p', 'Order date parsed by strftime', 'woocommerce' ), strtotime( $post_date) ) ) );

          $order_id = wp_insert_post( apply_filters( 'woocommerce_new_order_data', $order_data ), true );

          $order = wc_get_order( $order_id );
          $order->add_product( wc_get_product( $produto ), $quantidade);

          $order->add_order_note( "Esse pedido foi criado de maneira Manual" );
          
          // SALVAR HISTÓRICO
          $current_user = wp_get_current_user();
          $order->add_order_note( "Esse pedido foi criado pelo usuario: ".$current_user->user_email );

          $order->calculate_totals();

          // ADICIONAR NOTA AO PEDIDO
          if($nota!=""):

            $order->add_order_note( "Nota/Observação: ".$nota );
          
          endif;
          
          add_post_meta( $order_id, 'billing_cotasescolhidas', $cotas );

          $billing = array(
                 'first_name' => $primeiro_nome,
                 'last_name' => $sobrenome,
                 'email'      => $email,
                 'billing_cotasescolhidas' => $cotas);
          
          $order->set_address( $billing, 'billing' );

          // RETORNAR OS DADOS
          $data = array('sucesso' => "200", 'order' => $order_id, 'produto' => $produto);

          $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
          echo $json_string; 
          
          wp_die();

}

add_action('wp_ajax_pluginrifa_enviarpedido', 'pluginrifa_enviarpedido');
add_action('wp_ajax_nopriv_pluginrifa_enviarpedido', 'pluginrifa_enviarpedido' );


// CANCELAR UM PEDIDO
function pluginrifa_cancelarpedido(){

  $idPedido = $_POST["pedido"];

  $_order = new WC_Order( $idPedido ); 
  $_order->update_status('cancelled');

  // SALVAR HISTÓRICO
  $current_user = wp_get_current_user();
  $_order->add_order_note( "Esse pedido foi cancelado pelo colaborador: ".$current_user->user_email );

  // RETORNAR OS DADOS
  $data = array('sucesso' => "200", 'order' => $idPedido);

  $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
  echo $json_string; 
          
  wp_die();

}

add_action('wp_ajax_pluginrifa_cancelarpedido', 'pluginrifa_cancelarpedido');
add_action('wp_ajax_nopriv_pluginrifa_cancelarpedido', 'pluginrifa_cancelarpedido' );




// RECUPERAR DADOS PARA EDIÇÃO DO PEDIDO
function pluginrifa_dadospedido(){
   
          $pedido = $_POST["pedido"];

          $cotas = get_post_meta( $pedido, 'billing_cotasescolhidas', true );
           
          // RETORNAR OS DADOS
          $data = array('sucesso' => "200", 
                          'cotas' => $cotas);
          
          $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
          echo $json_string; 
          
          wp_die();

}

add_action('wp_ajax_pluginrifa_dadospedido', 'pluginrifa_dadospedido');
add_action('wp_ajax_nopriv_pluginrifa_dadospedido', 'pluginrifa_dadospedido' );





// EFETIVAMENTE SALVAR OS DADOS PEDIDO
function pluginrifa_salvareditarpedido(){

    $idPedido = $_POST["idPedido"];
    $cotas = $_POST["cotas"];
    $nota = $_POST["nota"];

          $order = wc_get_order( $idPedido );
          
          // ADICIONAR NOTA AO PEDIDO
          if($nota!=""):

            $order->add_order_note( "Nota/Observação: ".$nota );
          
          endif;

          $quebra = explode("-",$data);
          $data_final = $quebra[2]."/".$quebra[1]."/".$quebra[0];

          update_post_meta($idPedido,"billing_cotasescolhidas", $cotas);
         
          // SALVAR HISTÓRICO
          $current_user = wp_get_current_user();
          $order->add_order_note( "Esse pedido foi editado manualmente: ".$current_user->user_email );

          // RETORNAR OS DADOS
          $data = array('sucesso' => "200");
          
          $json_string = json_encode($data, JSON_PRETTY_PRINT);
     
          echo $json_string; 
          
          wp_die();

}

add_action('wp_ajax_pluginrifa_salvareditarpedido', 'pluginrifa_salvareditarpedido');
add_action('wp_ajax_nopriv_pluginrifa_salvareditarpedido', 'pluginrifa_salvareditarpedido' );



/**
*  ------------------------------------------------------------------------------------------------
*
*
*   LIMPAR A SESSÃO QUANDO O USUÄRIO CHEGAR NA PÄGINA DE CONCLUSÃO
*
*
*  ------------------------------------------------------------------------------------------------
*/
add_action( 'woocommerce_order_details_before_order_table', 'trusted_shops_thankyou_clearlsrifa', 15, 1 );
function trusted_shops_thankyou_clearlsrifa( $order ) {

  ?>
  
  <script type="text/javascript">
      localStorage.setItem("dadosCheckout","");
      console.log("%c SESSAO LIMPA APÓS A COMPRA","background:#fff000;color:#000;");
  </script>

  <?php

  
}


/**
*  ------------------------------------------------------------------------------------------------
*
*
*   PAGE TEMPLATES
*
*
*  ------------------------------------------------------------------------------------------------
*/
class PageTemplater {

	/**
	 * A reference to an instance of this class.
	 */
	private static $instance;

	/**
	 * The array of templates that this plugin tracks.
	 */
	protected $templates;

	/**
	 * Returns an instance of this class.
	 */
	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new PageTemplater();
		}

		return self::$instance;

	}

	/**
	 * Initializes the plugin by setting filters and administration functions.
	 */
	private function __construct() {

		$this->templates = array();


		// Add a filter to the attributes metabox to inject template into the cache.
		if ( version_compare( floatval( get_bloginfo( 'version' ) ), '4.7', '<' ) ) {

			// 4.6 and older
			add_filter(
				'page_attributes_dropdown_pages_args',
				array( $this, 'register_project_templates' )
			);

		} else {

			// Add a filter to the wp 4.7 version attributes metabox
			add_filter(
				'theme_page_templates', array( $this, 'add_new_template' )
			);

		}

		// Add a filter to the save post to inject out template into the page cache
		add_filter(
			'wp_insert_post_data',
			array( $this, 'register_project_templates' )
		);


		// Add a filter to the template include to determine if the page has our
		// template assigned and return it's path
		add_filter(
			'template_include',
			array( $this, 'view_project_template')
		);

		// Add your templates to this array.
		$this->templates = array(
			'templates/rifa-pages.php' => 'Página Rifa',
		);

	}

	/**
	 * Adds our template to the page dropdown for v4.7+
	 *
	 */
	public function add_new_template( $posts_templates ) {
		$posts_templates = array_merge( $posts_templates, $this->templates );
		return $posts_templates;
	}

	/**
	 * Adds our template to the pages cache in order to trick WordPress
	 * into thinking the template file exists where it doens't really exist.
	 */
	public function register_project_templates( $atts ) {

		// Create the key used for the themes cache
		$cache_key = 'page_templates-' . md5( get_theme_root() . '/' . get_stylesheet() );

		// Retrieve the cache list.
		// If it doesn't exist, or it's empty prepare an array
		$templates = wp_get_theme()->get_page_templates();
		if ( empty( $templates ) ) {
			$templates = array();
		}

		// New cache, therefore remove the old one
		wp_cache_delete( $cache_key , 'themes');

		// Now add our template to the list of templates by merging our templates
		// with the existing templates array from the cache.
		$templates = array_merge( $templates, $this->templates );

		// Add the modified cache to allow WordPress to pick it up for listing
		// available templates
		wp_cache_add( $cache_key, $templates, 'themes', 1800 );

		return $atts;

	}

	/**
	 * Checks if the template is assigned to the page
	 */
	public function view_project_template( $template ) {
		// Return the search template if we're searching (instead of the template for the first result)
		if ( is_search() ) {
			return $template;
		}

		// Get global post
		global $post;

		// Return template if post is empty
		if ( ! $post ) {
			return $template;
		}

		// Return default template if we don't have a custom one defined
		if ( ! isset( $this->templates[get_post_meta(
			$post->ID, '_wp_page_template', true
		)] ) ) {
			return $template;
		}

		// Allows filtering of file path
		$filepath = apply_filters( 'page_templater_plugin_dir_path', plugin_dir_path( __FILE__ ) );

		$file =  $filepath . get_post_meta(
			$post->ID, '_wp_page_template', true
		);

		// Just to be safe, we check if the file exist first
		if ( file_exists( $file ) ) {
			return $file;
		} else {
			echo $file;
		}

		// Return template
		return $template;

	}

}
add_action( 'plugins_loaded', array( 'PageTemplater', 'get_instance' ) );

		
/**
*  ------------------------------------------------------------------------------------------------
*
*
*   SALVAR BILLING_COTAS_ESCOLHIDAS & MOSTRAR OS NÚMEROS ESCOLHIDOS NA PÁGINA DE OBRIGADO
*
*
*  ------------------------------------------------------------------------------------------------
*/

//  ################################################
//
//  EXIBIR NA PÁGINA DE THANK YOU PAGE OS NUMEROS ESCOLHIDOS
//
//  ################################################
add_action( 'woocommerce_thankyou', 'exibir_meus_numeros_no_obrigado_rifa' );
  
function exibir_meus_numeros_no_obrigado_rifa() {

  $order_key = $_GET["key"];
  $order_id = wc_get_order_id_by_order_key($order_key); 

      $temp = explode(",",get_post_meta( $order_id, 'billing_cotasescolhidas', true ));

      $return_string = $product_name . "<br clear='both' />";

      $return_string = $return_string . "<div class='resumo-numeros-escolhidos winner-card__content'><div class='number-list-wrapper'>
      <h3 id='tituloResumoDosNumerosEscolhidos'>Números escolhidos</h3>
      <ul class='number-list'>";

      $a = 0;
      while($a<count($temp)):

        if($temp[$a]!=""): $return_string = $return_string . "<li>".$temp[$a]."</li>"; endif;

        $a++;
      endwhile;

      $return_string = $return_string . "</ul></div></div><br clear='both' />";

      echo $return_string;

}


//  ################################################
//
//  CAPTURAR A INFORMAÇÃO DOS NUMEROS ESCOLHIDOS
//  ISSO SÓ NAO ESTA FUNCIONANDO AQUI, POR QUE O POST É ENVIADO COMO REDIRECT PARA O CHECKOUT
//  E NAO NO ADD AO CARRINHO
//
//  ################################################
add_filter('woocommerce_add_cart_item_data','wdm_add_item_data',1,10);
function wdm_add_item_data($cart_item_data, $product_id) {

    global $woocommerce;

    if($_POST["cotas_escolhidas_input"]):

          $new_value = array();

          $billing_cotasescolhidas = $_POST["cotas_escolhidas_input"];

          $new_value['rifa']["billing_cotasescolhidas"] = $billing_cotasescolhidas;

          if(empty($cart_item_data)) {
            return $new_value;
          } else {
            return array_merge($cart_item_data, $new_value);
          }

    endif;

}

//  ################################################
//
//  LINKAR ITENS AO PRODUTO INDIVIDUALMENTE
//
//  ################################################
add_filter('woocommerce_get_cart_item_from_session', 'wdm_get_cart_items_from_session', 1, 3 );
function wdm_get_cart_items_from_session($item,$values,$key) {

    if (array_key_exists( 'rifa', $values ) ) {
        $item['rifa'] = $values['rifa'];
    }

    return $item;
}


//  ################################################
//
//  EXIBIR ITENS NO CARRINHO NO CHECKOUT
//
//  ################################################
add_filter('woocommerce_cart_item_name','add_usr_custom_session',1,3);
function add_usr_custom_session($product_name, $values, $cart_item_key ) {

  if($values['rifa']!="" && $values['rifa']['billing_cotasescolhidas']!=""):

      $temp = explode(",",$values['rifa']['billing_cotasescolhidas']);

      $return_string = $product_name . "<br />";

      $return_string = $return_string . "<div class='resumo-numeros-escolhidos'>";

      $a = 0;
      while($a<count($temp)):

        if($temp[$a]!=""): $return_string = $return_string . "<li>".$temp[$a]."</li>"; endif;

        $a++;
      endwhile;

      $return_string = $return_string . "</div>";

        return $return_string;

    endif;

}




//  ################################################
//
//  EXIBIR ESSAS INFOS NO E-MAIL E NO PEDIDO (INTERNO)
//
//  ################################################
add_action('woocommerce_add_order_item_meta','wdm_add_values_to_order_item_meta',1,2);
function wdm_add_values_to_order_item_meta($item_id, $values) {

    global $woocommerce,$wpdb;

    if($values['rifa']):
     
        if($values['rifa']['billing_cotasescolhidas']):

           wc_add_order_item_meta($item_id,'billing_cotasescolhidas',$values['rifa']['billing_cotasescolhidas']);

           wc_add_order_item_meta($item_id,'billing_cotasescolhidas_previa',"Números escolhidos: ".$values['rifa']['billing_cotasescolhidas']);
        
        endif;

    endif;

}



?>